DOMStringList class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

DOMStringList({num? length, bool contains(String)?, String? item(num)?})
factory

Properties

contains ↔ bool Function(String)

Available on DOMStringList, provided by the DOMStringList$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
item ↔ String? Function(num)

Available on DOMStringList, provided by the DOMStringList$Typings extension

getter/setter pair
length → num

Available on DOMStringList, provided by the DOMStringList$Typings extension

Returns the number of strings in strings.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](num index) → String

Available on DOMStringList, provided by the DOMStringList$Typings extension

operator []=(num index, String value) → void

Available on DOMStringList, provided by the DOMStringList$Typings extension