Process<T extends RunOptions> class

  • @deprecated Use {@linkcode Deno.Command} instead.

Represents an instance of a sub process that is returned from {@linkcode Deno.run} which can be used to manage the sub-process.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

Process()

Properties

hashCode → int
The hash code for this object.
no setterinherited
pid → num

Available on Process<T>, provided by the Process$Typings extension

The operating system's process ID for the sub-process.
no setter
rid → num

Available on Process<T>, provided by the Process$Typings extension

The resource ID of the sub-process.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stderr → dynamic

Available on Process<T>, provided by the Process$Typings extension

A reference to the sub-processes stderr, which allows interacting with the sub-process at a low level.
no setter
stdin → dynamic

Available on Process<T>, provided by the Process$Typings extension

A reference to the sub-processes stdin, which allows interacting with the sub-process at a low level.
no setter
stdout → dynamic

Available on Process<T>, provided by the Process$Typings extension

A reference to the sub-processes stdout, which allows interacting with the sub-process at a low level.
no setter

Methods

close() → void

Available on Process<T>, provided by the Process$Typings extension

Clean up resources associated with the sub-process instance.
kill([Signal? signo]) → void

Available on Process<T>, provided by the Process$Typings extension

Send a signal to process. Default signal is "SIGTERM".
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
output() → Future<Uint8List>

Available on Process<T>, provided by the Process$Typings extension

Buffer the stdout until EOF and return it as Uint8Array.
status() → Future<ProcessStatus>

Available on Process<T>, provided by the Process$Typings extension

Wait for the process to exit and return its exit status.
stderrOutput() → Future<Uint8List>

Available on Process<T>, provided by the Process$Typings extension

Buffer the stderr until EOF and return it as Uint8Array.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited