TextEncoder class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

TextEncoder()
factory

Properties

encode ↔ Uint8List Function([String?])

Available on TextEncoder, provided by the TextEncoder$Typings extension

getter/setter pair
encodeInto ↔ TextEncoderEncodeIntoResult Function(String, Uint8List)

Available on TextEncoder, provided by the TextEncoder$Typings extension

getter/setter pair
encoding → String

Available on TextEncoder, provided by the TextEncoder$Typings extension

Returns "utf-8".
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

encoding → String
Returns "utf-8".
no setter