URLPatternInit class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

URLPatternInit({String? protocol, String? username, String? password, String? hostname, String? port, String? pathname, String? search, String? hash, String? baseURL})
factory

Properties

baseURL ↔ String?

Available on URLPatternInit, provided by the URLPatternInit$Typings extension

getter/setter pair
hash ↔ String?

Available on URLPatternInit, provided by the URLPatternInit$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hostname ↔ String?

Available on URLPatternInit, provided by the URLPatternInit$Typings extension

getter/setter pair
password ↔ String?

Available on URLPatternInit, provided by the URLPatternInit$Typings extension

getter/setter pair
pathname ↔ String?

Available on URLPatternInit, provided by the URLPatternInit$Typings extension

getter/setter pair
port ↔ String?

Available on URLPatternInit, provided by the URLPatternInit$Typings extension

getter/setter pair
protocol ↔ String?

Available on URLPatternInit, provided by the URLPatternInit$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Available on URLPatternInit, provided by the URLPatternInit$Typings extension

getter/setter pair
username ↔ String?

Available on URLPatternInit, provided by the URLPatternInit$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited