UnixAddr class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

UnixAddr({TransportOptions? transport, String? path})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
path ↔ String

Available on UnixAddr, provided by the UnixAddr$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transport ↔ TransportOptions

Available on UnixAddr, provided by the UnixAddr$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited