WebSocketEventMap class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

WebSocketEventMap({CloseEvent? close, Event? error, MessageEvent? message, Event? open})
factory

Properties

close ↔ CloseEvent

Available on WebSocketEventMap, provided by the WebSocketEventMap$Typings extension

getter/setter pair
error ↔ Event

Available on WebSocketEventMap, provided by the WebSocketEventMap$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ MessageEvent

Available on WebSocketEventMap, provided by the WebSocketEventMap$Typings extension

getter/setter pair
open ↔ Event

Available on WebSocketEventMap, provided by the WebSocketEventMap$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited