WriteFileOptions$Typings extension

on

Properties

append ↔ bool?

Available on WriteFileOptions, provided by the WriteFileOptions$Typings extension

If set to true, will append to a file instead of overwriting previous contents.
getter/setter pair
create ↔ bool?

Available on WriteFileOptions, provided by the WriteFileOptions$Typings extension

Sets the option to allow creating a new file, if one doesn't already exist at the specified path.
getter/setter pair
createNew ↔ bool?

Available on WriteFileOptions, provided by the WriteFileOptions$Typings extension

If set to true, no file, directory, or symlink is allowed to exist at the target location. When createNew is set to true, create is ignored.
getter/setter pair
mode ↔ num?

Available on WriteFileOptions, provided by the WriteFileOptions$Typings extension

Permissions always applied to file.
getter/setter pair
signal ↔ AbortSignal?

Available on WriteFileOptions, provided by the WriteFileOptions$Typings extension

An abort signal to allow cancellation of the file write operation.
getter/setter pair