AggregateError class

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

AggregateError.$1()
factory
AggregateError.$2(Iterable errors, [String? message])
factory
AggregateError.$3(Iterable errors, [String? message, ErrorOptions? options])
factory

Properties

cause ↔ Object?

Available on Error, provided by the Error$Typings extension

getter/setter pair
errors ↔ List

Available on AggregateError, provided by the AggregateError$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String

Available on Error, provided by the Error$Typings extension

getter/setter pair
name ↔ String

Available on Error, provided by the Error$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stack ↔ String?

Available on Error, provided by the Error$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited