Animatable class

Implementers
Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

Animatable({Animation animate([dynamic, Object?])?, List<Animation> getAnimations([GetAnimationsOptions?])?})
factory

Properties

animate ↔ Animation Function([dynamic, Object?])

Available on Animatable, provided by the Animatable$Typings extension

getter/setter pair
getAnimations ↔ List<Animation> Function([GetAnimationsOptions?])

Available on Animatable, provided by the Animatable$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited