Array<T> class

Implementers
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

Array.$1()
factory
Array.$2([num? arrayLength])
factory
Array.$3([Iterable? items])
factory

Properties

at ↔ T? Function(num)

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
copyWithin ↔ Array Function(num, num, [num?])

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
entries ↔ IterableIterator<(num, T)> Function()

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
every → ({dynamic Function<S extends T>(dynamic predicate(T, num, List<T>), [dynamic thisArg]) $1, bool Function(Object? predicate(T, num, List<T>), [dynamic thisArg]) $2})

Available on Array<T>, provided by the Array$Typings extension

Overload accessor: $1, $2
no setter
fill ↔ Array Function(T, [num?, num?])

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
filter → ({List<S> Function<S extends T>(dynamic predicate(T, num, List<T>), [dynamic thisArg]) $1, List<T> Function(Object? predicate(T, num, List<T>), [dynamic thisArg]) $2})

Available on Array<T>, provided by the Array$Typings extension

Overload accessor: $1, $2
no setter
find → ({S? Function<S extends T>(dynamic predicate(T, num, List<T>), [dynamic thisArg]) $1, T? Function(Object? predicate(T, num, List<T>), [dynamic thisArg]) $2})

Available on Array<T>, provided by the Array$Typings extension

Overload accessor: $1, $2
no setter
findIndex ↔ num Function(Object? (T, num, List<T>), [dynamic])

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
findLast → ({S? Function<S extends T>(dynamic predicate(T, num, List<T>), [dynamic thisArg]) $1, T? Function(Object? predicate(T, num, List<T>), [dynamic thisArg]) $2})

Available on Array<T>, provided by the Array$Typings extension

Overload accessor: $1, $2
no setter
findLastIndex ↔ num Function(Object? (T, num, List<T>), [dynamic])

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
flat ↔ List Function<A, D extends num>([D?])

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
flatMap ↔ List<U> Function<U, This>(Object (T, num, List<T>), [This?])

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
forEach ↔ void Function(void (T, num, List<T>), [dynamic])

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
includes ↔ bool Function(T, [num?])

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
indexOf ↔ num Function(T, [num?])

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
join ↔ String Function([String?])

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
keys ↔ IterableIterator<num> Function()

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
lastIndexOf ↔ num Function(T, [num?])

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
length ↔ num

Available on Array<T>, provided by the Array$Typings extension

Gets or sets the length of the array. This is a number one higher than the highest index in the array.
getter/setter pair
map ↔ List<U> Function<U>(U (T, num, List<T>), [dynamic])

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
pop ↔ T? Function()

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
push ↔ num Function([Iterable?])

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
reduce → ({T Function(T callbackfn(T, T, num, List<T>), T initialValue) $1, U Function<U>(U callbackfn(U, T, num, List<T>), U initialValue) $2})

Available on Array<T>, provided by the Array$Typings extension

Overload accessor: $1, $2
no setter
reduceRight → ({T Function(T callbackfn(T, T, num, List<T>), T initialValue) $1, U Function<U>(U callbackfn(U, T, num, List<T>), U initialValue) $2})

Available on Array<T>, provided by the Array$Typings extension

Overload accessor: $1, $2
no setter
reverse ↔ List<T> Function()

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shift ↔ T? Function()

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
slice ↔ List<T> Function([num?, num?])

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
some ↔ bool Function(Object? predicate(T, num, List<T>), [dynamic thisArg])

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
sort ↔ Array Function([num (T, T)?])

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
toLocaleString ↔ String Function()

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
toReversed ↔ List<T> Function()

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
toSorted ↔ List<T> Function([num (T, T)?])

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
toString$ ↔ String Function()

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
unshift ↔ num Function([Iterable?])

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
values ↔ IterableIterator<T> Function()

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair
with$ ↔ List<T> Function(num, T)

Available on Array<T>, provided by the Array$Typings extension

getter/setter pair

Methods

concat([Iterable? items]) → List<T>

Available on Array<T>, provided by the Array$Typings extension

Combines two or more arrays. This method returns a new array without modifying any existing arrays. @param items Additional arrays and/or items to add to the end of the array.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
splice(num start, num deleteCount, [Iterable? items]) → List<T>

Available on Array<T>, provided by the Array$Typings extension

Removes elements from an array and, if necessary, inserts new elements in their place, returning the deleted elements. @param start The zero-based location in the array from which to start removing elements. @param deleteCount The number of elements to remove. @param items Elements to insert into the array in place of the deleted elements. @returns An array containing the elements that were deleted.
toSpliced(num start, num deleteCount, [Iterable? items]) → List<T>

Available on Array<T>, provided by the Array$Typings extension

Copies an array and removes elements and, if necessary, inserts new elements in their place. Returns the copied array. @param start The zero-based location in the array from which to start removing elements. @param deleteCount The number of elements to remove. @param items Elements to insert into the copied array in place of the deleted elements. @returns The copied array.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](num index) → T

Available on Array<T>, provided by the Array$Typings extension

operator []=(num index, T value) → void

Available on Array<T>, provided by the Array$Typings extension

Static Properties

from → ({List<T> Function<T>(From iterable) $1, List<U> Function<T, U>(List<T> arrayLike, U mapfn(T, num), [dynamic thisArg]) $2, List<U> Function<T, U>(FromCommon iterable, U mapfn(T, num), [dynamic thisArg]) $3})
Overload accessor: $1, $2, $3
no setter
isArray ↔ dynamic Function([dynamic])
getter/setter pair
of ↔ List<T> Function<T>([Iterable?])
getter/setter pair