ArrayBufferView class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

ArrayBufferView({dynamic buffer, num? byteLength, num? byteOffset})
factory

Properties

buffer ↔ dynamic

Available on ArrayBufferView, provided by the ArrayBufferView$Typings extension

The ArrayBuffer instance referenced by the array.
getter/setter pair
byteLength ↔ num

Available on ArrayBufferView, provided by the ArrayBufferView$Typings extension

The length in bytes of the array.
getter/setter pair
byteOffset ↔ num

Available on ArrayBufferView, provided by the ArrayBufferView$Typings extension

The offset in bytes of the array.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited