AsyncIterableIterator<T> class

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

AsyncIterableIterator({Future<IteratorResult<T, TReturn>> next([Iterable?])?, Future<IteratorResult<T, TReturn>> return$([FutureOr?])?, Future<IteratorResult<T, TReturn>> throw$([dynamic])?})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
next ↔ Future<IteratorResult<T, TReturn>> Function([Iterable?])

Available on AsyncIterator<T, TReturn, TNext>, provided by the AsyncIterator$Typings extension

getter/setter pair
return$ ↔ Future<IteratorResult<T, TReturn>> Function([FutureOr<TReturn>?])

Available on AsyncIterator<T, TReturn, TNext>, provided by the AsyncIterator$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
throw$ ↔ Future<IteratorResult<T, TReturn>> Function([dynamic])

Available on AsyncIterator<T, TReturn, TNext>, provided by the AsyncIterator$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited