AudioBufferSourceOptions class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

AudioBufferSourceOptions({AudioBuffer? buffer, num? detune, bool? loop, num? loopEnd, num? loopStart, num? playbackRate})
factory

Properties

buffer ↔ AudioBuffer?

Available on AudioBufferSourceOptions, provided by the AudioBufferSourceOptions$Typings extension

getter/setter pair
detune ↔ num?

Available on AudioBufferSourceOptions, provided by the AudioBufferSourceOptions$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
loop ↔ bool?

Available on AudioBufferSourceOptions, provided by the AudioBufferSourceOptions$Typings extension

getter/setter pair
loopEnd ↔ num?

Available on AudioBufferSourceOptions, provided by the AudioBufferSourceOptions$Typings extension

getter/setter pair
loopStart ↔ num?

Available on AudioBufferSourceOptions, provided by the AudioBufferSourceOptions$Typings extension

getter/setter pair
playbackRate ↔ num?

Available on AudioBufferSourceOptions, provided by the AudioBufferSourceOptions$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited