BigInt64Array class

A typed array of 64-bit signed integer values. The contents are initialized to 0. If the requested number of bytes could not be allocated, an exception is raised.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

BigInt64Array.$1()
factory
BigInt64Array.$2([num? length])
factory
BigInt64Array.$3(Iterable<int> array)
factory
BigInt64Array.$4(dynamic buffer, [num? byteOffset, num? length])
factory

Properties

at ↔ int? Function(num)

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
buffer → dynamic

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

The ArrayBuffer instance referenced by the array.
no setter
byteLength → num

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

The length in bytes of the array.
no setter
byteOffset → num

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

The offset in bytes of the array.
no setter
bytesPerElement → num

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

The size in bytes of each element in the array.
no setter
copyWithin ↔ BigInt64Array Function(num, num, [num?])

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
entries ↔ IterableIterator<(num, int)> Function()

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
every ↔ bool Function(bool (int, num, BigInt64Array), [dynamic])

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
fill ↔ BigInt64Array Function(int, [num?, num?])

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
filter ↔ BigInt64Array Function(dynamic (int, num, BigInt64Array), [dynamic])

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
find ↔ int? Function(bool (int, num, BigInt64Array), [dynamic])

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
findIndex ↔ num Function(bool (int, num, BigInt64Array), [dynamic])

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
findLast → ({S? Function<S extends int>(dynamic predicate(int, num, BigInt64Array), [dynamic thisArg]) $1, int? Function(Object? predicate(int, num, BigInt64Array), [dynamic thisArg]) $2})

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

Overload accessor: $1, $2
no setter
findLastIndex ↔ num Function(Object? (int, num, BigInt64Array), [dynamic])

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
forEach ↔ void Function(void (int, num, BigInt64Array), [dynamic])

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
includes ↔ bool Function(int, [num?])

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
indexOf ↔ num Function(int, [num?])

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
join ↔ String Function([String?])

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
keys ↔ IterableIterator<num> Function()

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
lastIndexOf ↔ num Function(int, [num?])

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
length → num

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

The length of the array.
no setter
map ↔ BigInt64Array Function(int (int, num, BigInt64Array), [dynamic])

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
reduce → ({int Function(int callbackfn(int, int, num, BigInt64Array)) $1, U Function<U>(U callbackfn(U, int, num, BigInt64Array), U initialValue) $2})

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

Overload accessor: $1, $2
no setter
reduceRight → ({int Function(int callbackfn(int, int, num, BigInt64Array)) $1, U Function<U>(U callbackfn(U, int, num, BigInt64Array), U initialValue) $2})

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

Overload accessor: $1, $2
no setter
reverse ↔ BigInt64Array Function()

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
set ↔ void Function(List<int>, [num?])

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
slice ↔ BigInt64Array Function([num?, num?])

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
some ↔ bool Function(bool (int, num, BigInt64Array), [dynamic])

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
sort ↔ BigInt64Array Function([Object (int, int)?])

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
subarray ↔ BigInt64Array Function([num?, num?])

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
toLocaleString ↔ String Function()

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
toReversed ↔ BigInt64Array Function()

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
toSorted ↔ BigInt64Array Function([num (int, int)?])

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
toString$ ↔ String Function()

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
valueOf ↔ BigInt64Array Function()

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
values ↔ IterableIterator<int> Function()

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair
with$ ↔ BigInt64Array Function(num, int)

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](num index) → int

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

operator []=(num index, int value) → void

Available on BigInt64Array, provided by the BigInt64Array$Typings extension

Static Properties

of ↔ BigInt64Array Function([Iterable?])
getter/setter pair

Static Methods

from<U>(List<U> arrayLike, int mapfn(U, num), [dynamic thisArg]) → BigInt64Array
Creates an array from an array-like or iterable object.