CSSAnimation class

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

CSSAnimation()
factory

Properties

addEventListener → ({void Function<K$>(AnimationEventMap<K$> type, dynamic listener(K$), [Object? options]) $1, void Function(String type, Object listener, [Object? options]) $2})

Available on Animation, provided by the Animation$Typings extension

Overload accessor: $1, $2
no setter
addEventListener → ({void Function<K$>(AnimationEventMap<K$> type, dynamic listener(K$), [Object? options]) $1, void Function(String type, Object listener, [Object? options]) $2})

Available on CSSAnimation, provided by the CSSAnimation$Typings extension

Overload accessor: $1, $2
no setter
addEventListener ↔ void Function(String, [Object?, Object?])

Available on EventTarget, provided by the EventTarget$Typings extension

getter/setter pair
animationName → String

Available on CSSAnimation, provided by the CSSAnimation$Typings extension

MDN Reference
no setter
cancel ↔ void Function()

Available on Animation, provided by the Animation$Typings extension

getter/setter pair
commitStyles ↔ void Function()

Available on Animation, provided by the Animation$Typings extension

getter/setter pair
currentTime ↔ Object?

Available on Animation, provided by the Animation$Typings extension

MDN Reference
getter/setter pair
dispatchEvent ↔ bool Function(Event event)

Available on EventTarget, provided by the EventTarget$Typings extension

getter/setter pair
effect ↔ AnimationEffect?

Available on Animation, provided by the Animation$Typings extension

MDN Reference
getter/setter pair
finish ↔ void Function()

Available on Animation, provided by the Animation$Typings extension

getter/setter pair
finished → Future<Animation>

Available on Animation, provided by the Animation$Typings extension

MDN Reference
no setter
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String

Available on Animation, provided by the Animation$Typings extension

MDN Reference
getter/setter pair
oncancel ↔ dynamic Function(AnimationPlaybackEvent)?

Available on Animation, provided by the Animation$Typings extension

MDN Reference
getter/setter pair
onfinish ↔ dynamic Function(AnimationPlaybackEvent)?

Available on Animation, provided by the Animation$Typings extension

MDN Reference
getter/setter pair
onremove ↔ dynamic Function(Event)?

Available on Animation, provided by the Animation$Typings extension

MDN Reference
getter/setter pair
pause ↔ void Function()

Available on Animation, provided by the Animation$Typings extension

getter/setter pair
pending → bool

Available on Animation, provided by the Animation$Typings extension

MDN Reference
no setter
persist ↔ void Function()

Available on Animation, provided by the Animation$Typings extension

getter/setter pair
play ↔ void Function()

Available on Animation, provided by the Animation$Typings extension

getter/setter pair
playbackRate ↔ num

Available on Animation, provided by the Animation$Typings extension

MDN Reference
getter/setter pair
playState → AnimationPlayState

Available on Animation, provided by the Animation$Typings extension

MDN Reference
no setter
ready → Future<Animation>

Available on Animation, provided by the Animation$Typings extension

MDN Reference
no setter
removeEventListener → ({void Function<K$>(AnimationEventMap<K$> type, dynamic listener(K$), [Object? options]) $1, void Function(String type, Object listener, [Object? options]) $2})

Available on Animation, provided by the Animation$Typings extension

Overload accessor: $1, $2
no setter
removeEventListener → ({void Function<K$>(AnimationEventMap<K$> type, dynamic listener(K$), [Object? options]) $1, void Function(String type, Object listener, [Object? options]) $2})

Available on CSSAnimation, provided by the CSSAnimation$Typings extension

Overload accessor: $1, $2
no setter
removeEventListener ↔ void Function(String, [Object?, Object?])

Available on EventTarget, provided by the EventTarget$Typings extension

getter/setter pair
replaceState → AnimationReplaceState

Available on Animation, provided by the Animation$Typings extension

MDN Reference
no setter
reverse ↔ void Function()

Available on Animation, provided by the Animation$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ Object?

Available on Animation, provided by the Animation$Typings extension

MDN Reference
getter/setter pair
timeline ↔ AnimationTimeline?

Available on Animation, provided by the Animation$Typings extension

MDN Reference
getter/setter pair
updatePlaybackRate ↔ void Function(num handle)

Available on Animation, provided by the Animation$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited