CSSFontFaceRule class

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

CSSFontFaceRule()
factory

Properties

charsetRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
cssText ↔ String

Available on CSSRule, provided by the CSSRule$Typings extension

MDN Reference
getter/setter pair
fontFaceRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
importRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
keyframeRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
keyframesRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
mediaRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
namespaceRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
pageRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
parentRule → CSSRule?

Available on CSSRule, provided by the CSSRule$Typings extension

MDN Reference
no setter
parentStyleSheet → CSSStyleSheet?

Available on CSSRule, provided by the CSSRule$Typings extension

MDN Reference
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → CSSStyleDeclaration

Available on CSSFontFaceRule, provided by the CSSFontFaceRule$Typings extension

MDN Reference
no setter
styleRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
supportsRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
type → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited