CSSKeyframesRule class

An object representing a complete set of keyframes for a CSS animation. It corresponds to the contains of a whole @keyframes at-rule. It implements the CSSRule interface with a type value of 7 (CSSRule.KEYFRAMES_RULE).

MDN Reference

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

CSSKeyframesRule()
factory

Properties

appendRule ↔ void Function(String)

Available on CSSKeyframesRule, provided by the CSSKeyframesRule$Typings extension

getter/setter pair
charsetRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
cssRules → CSSRuleList

Available on CSSKeyframesRule, provided by the CSSKeyframesRule$Typings extension

MDN Reference
no setter
cssText ↔ String

Available on CSSRule, provided by the CSSRule$Typings extension

MDN Reference
getter/setter pair
deleteRule ↔ void Function(String)

Available on CSSKeyframesRule, provided by the CSSKeyframesRule$Typings extension

getter/setter pair
findRule ↔ CSSKeyframeRule? Function(String)

Available on CSSKeyframesRule, provided by the CSSKeyframesRule$Typings extension

getter/setter pair
fontFaceRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
importRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
keyframeRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
keyframesRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
length → num

Available on CSSKeyframesRule, provided by the CSSKeyframesRule$Typings extension

no setter
mediaRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
name ↔ String

Available on CSSKeyframesRule, provided by the CSSKeyframesRule$Typings extension

MDN Reference
getter/setter pair
namespaceRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
pageRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
parentRule → CSSRule?

Available on CSSRule, provided by the CSSRule$Typings extension

MDN Reference
no setter
parentStyleSheet → CSSStyleSheet?

Available on CSSRule, provided by the CSSRule$Typings extension

MDN Reference
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
styleRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
supportsRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
type → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](num index) → CSSKeyframeRule

Available on CSSKeyframesRule, provided by the CSSKeyframesRule$Typings extension

operator []=(num index, CSSKeyframeRule value) → void

Available on CSSKeyframesRule, provided by the CSSKeyframesRule$Typings extension