CSSMathNegate class

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

CSSMathNegate(Object arg)
factory

Properties

add ↔ CSSNumericValue Function([Iterable?])

Available on CSSNumericValue, provided by the CSSNumericValue$Typings extension

getter/setter pair
div ↔ CSSNumericValue Function([Iterable?])

Available on CSSNumericValue, provided by the CSSNumericValue$Typings extension

getter/setter pair
equals ↔ bool Function([Iterable?])

Available on CSSNumericValue, provided by the CSSNumericValue$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
max ↔ CSSNumericValue Function([Iterable?])

Available on CSSNumericValue, provided by the CSSNumericValue$Typings extension

getter/setter pair
min ↔ CSSNumericValue Function([Iterable?])

Available on CSSNumericValue, provided by the CSSNumericValue$Typings extension

getter/setter pair
mul ↔ CSSNumericValue Function([Iterable?])

Available on CSSNumericValue, provided by the CSSNumericValue$Typings extension

getter/setter pair
operator → CSSMathOperator

Available on CSSMathValue, provided by the CSSMathValue$Typings extension

MDN Reference
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sub ↔ CSSNumericValue Function([Iterable?])

Available on CSSNumericValue, provided by the CSSNumericValue$Typings extension

getter/setter pair
to ↔ CSSUnitValue Function(String)

Available on CSSNumericValue, provided by the CSSNumericValue$Typings extension

getter/setter pair
toString$ ↔ String Function()

Available on CSSStyleValue, provided by the CSSStyleValue$Typings extension

getter/setter pair
toSum ↔ CSSMathSum Function([Iterable?])

Available on CSSNumericValue, provided by the CSSNumericValue$Typings extension

getter/setter pair
type ↔ CSSNumericType Function()

Available on CSSNumericValue, provided by the CSSNumericValue$Typings extension

getter/setter pair
value → CSSNumericValue

Available on CSSMathNegate, provided by the CSSMathNegate$Typings extension

MDN Reference
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited