CSSPropertyRule class

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

CSSPropertyRule()
factory

Properties

charsetRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
cssText ↔ String

Available on CSSRule, provided by the CSSRule$Typings extension

MDN Reference
getter/setter pair
fontFaceRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
importRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
inherits → bool

Available on CSSPropertyRule, provided by the CSSPropertyRule$Typings extension

MDN Reference
no setter
initialValue → String?

Available on CSSPropertyRule, provided by the CSSPropertyRule$Typings extension

MDN Reference
no setter
keyframeRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
keyframesRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
mediaRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
name → String

Available on CSSPropertyRule, provided by the CSSPropertyRule$Typings extension

MDN Reference
no setter
namespaceRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
pageRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
parentRule → CSSRule?

Available on CSSRule, provided by the CSSRule$Typings extension

MDN Reference
no setter
parentStyleSheet → CSSStyleSheet?

Available on CSSRule, provided by the CSSRule$Typings extension

MDN Reference
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
styleRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
supportsRule → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter
syntax → String

Available on CSSPropertyRule, provided by the CSSPropertyRule$Typings extension

MDN Reference
no setter
type → num

Available on CSSRule, provided by the CSSRule$Typings extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited