CSSStyleSheet class

A single CSS style sheet. It inherits properties and methods from its parent, StyleSheet.

MDN Reference

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

CSSStyleSheet([CSSStyleSheetInit? options])
factory

Properties

addRule ↔ num Function([String?, String?, num?])

Available on CSSStyleSheet, provided by the CSSStyleSheet$Typings extension

getter/setter pair
cssRules → CSSRuleList

Available on CSSStyleSheet, provided by the CSSStyleSheet$Typings extension

MDN Reference
no setter
deleteRule ↔ void Function(num handle)

Available on CSSStyleSheet, provided by the CSSStyleSheet$Typings extension

getter/setter pair
disabled ↔ bool

Available on StyleSheet, provided by the StyleSheet$Typings extension

MDN Reference
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
href → String?

Available on StyleSheet, provided by the StyleSheet$Typings extension

MDN Reference
no setter
insertRule ↔ num Function(String, [num?])

Available on CSSStyleSheet, provided by the CSSStyleSheet$Typings extension

getter/setter pair
media → MediaList

Available on StyleSheet, provided by the StyleSheet$Typings extension

MDN Reference
no setter
ownerNode → Node?

Available on StyleSheet, provided by the StyleSheet$Typings extension

MDN Reference
no setter
ownerRule → CSSRule?

Available on CSSStyleSheet, provided by the CSSStyleSheet$Typings extension

MDN Reference
no setter
parentStyleSheet → CSSStyleSheet?

Available on StyleSheet, provided by the StyleSheet$Typings extension

MDN Reference
no setter
removeRule ↔ void Function([num? id])

Available on CSSStyleSheet, provided by the CSSStyleSheet$Typings extension

getter/setter pair
replace ↔ Future<CSSStyleSheet> Function(String)

Available on CSSStyleSheet, provided by the CSSStyleSheet$Typings extension

getter/setter pair
replaceSync ↔ void Function(String)

Available on CSSStyleSheet, provided by the CSSStyleSheet$Typings extension

getter/setter pair
rules → CSSRuleList

Available on CSSStyleSheet, provided by the CSSStyleSheet$Typings extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?

Available on StyleSheet, provided by the StyleSheet$Typings extension

MDN Reference
no setter
type → String

Available on StyleSheet, provided by the StyleSheet$Typings extension

MDN Reference
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited