ComputedKeyframe class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

ComputedKeyframe({CompositeOperationOrAuto? composite, num? computedOffset, String? easing, num? offset})
factory

Properties

composite ↔ CompositeOperationOrAuto

Available on ComputedKeyframe, provided by the ComputedKeyframe$Typings extension

getter/setter pair
computedOffset ↔ num

Available on ComputedKeyframe, provided by the ComputedKeyframe$Typings extension

getter/setter pair
easing ↔ String

Available on ComputedKeyframe, provided by the ComputedKeyframe$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
offset ↔ num?

Available on ComputedKeyframe, provided by the ComputedKeyframe$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](String index) → dynamic

Available on ComputedKeyframe, provided by the ComputedKeyframe$Typings extension

operator []=(String index, dynamic value) → void

Available on ComputedKeyframe, provided by the ComputedKeyframe$Typings extension