ConcatArray<T> class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

ConcatArray({num? length, String join([String?])?, List slice([num?, num?])?})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
join ↔ String Function([String?])

Available on ConcatArray<T>, provided by the ConcatArray$Typings extension

getter/setter pair
length → num

Available on ConcatArray<T>, provided by the ConcatArray$Typings extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slice ↔ List<T> Function([num?, num?])

Available on ConcatArray<T>, provided by the ConcatArray$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](num index) → T

Available on ConcatArray<T>, provided by the ConcatArray$Typings extension