CryptoKey class

The CryptoKey dictionary of the Web Crypto API represents a cryptographic key. Available only in secure contexts.

MDN Reference

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

CryptoKey()
factory

Properties

algorithm → KeyAlgorithm

Available on CryptoKey, provided by the CryptoKey$Typings extension

MDN Reference
no setter
extractable → bool

Available on CryptoKey, provided by the CryptoKey$Typings extension

MDN Reference
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → KeyType

Available on CryptoKey, provided by the CryptoKey$Typings extension

MDN Reference
no setter
usages → List<KeyUsage>

Available on CryptoKey, provided by the CryptoKey$Typings extension

MDN Reference
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited