DOMImplementation class

An object providing methods which are not dependent on any particular document. Such an object is returned by the Document.implementation property.

MDN Reference

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

DOMImplementation()
factory

Properties

createDocument ↔ XMLDocument Function([String?, String?, DocumentType?])

Available on DOMImplementation, provided by the DOMImplementation$Typings extension

getter/setter pair
createDocumentType ↔ DocumentType Function(String, String, String)

Available on DOMImplementation, provided by the DOMImplementation$Typings extension

getter/setter pair
createHTMLDocument ↔ Document Function([String?])

Available on DOMImplementation, provided by the DOMImplementation$Typings extension

getter/setter pair
hasFeature ↔ bool Function([Iterable?])

Available on DOMImplementation, provided by the DOMImplementation$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited