DOMPointInit class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

DOMPointInit({num? w, num? x, num? y, num? z})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
w ↔ num?

Available on DOMPointInit, provided by the DOMPointInit$Typings extension

getter/setter pair
x ↔ num?

Available on DOMPointInit, provided by the DOMPointInit$Typings extension

getter/setter pair
y ↔ num?

Available on DOMPointInit, provided by the DOMPointInit$Typings extension

getter/setter pair
z ↔ num?

Available on DOMPointInit, provided by the DOMPointInit$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited