DOMPointReadOnly class

Implementers
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

DOMPointReadOnly([num? x, num? y, num? z, num? w])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
matrixTransform ↔ DOMPoint Function([DOMMatrixInit?])

Available on DOMPointReadOnly, provided by the DOMPointReadOnly$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJSON ↔ dynamic Function()

Available on DOMPointReadOnly, provided by the DOMPointReadOnly$Typings extension

getter/setter pair
w → num

Available on DOMPointReadOnly, provided by the DOMPointReadOnly$Typings extension

MDN Reference
no setter
x → num

Available on DOMPointReadOnly, provided by the DOMPointReadOnly$Typings extension

MDN Reference
no setter
y → num

Available on DOMPointReadOnly, provided by the DOMPointReadOnly$Typings extension

MDN Reference
no setter
z → num

Available on DOMPointReadOnly, provided by the DOMPointReadOnly$Typings extension

MDN Reference
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

fromPoint ↔ DOMPointReadOnly Function([DOMPointInit?])
getter/setter pair