DOMRect class

Implemented types
Implementers
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

DOMRect([num? x, num? y, num? width, num? height])
factory

Properties

bottom → num

Available on DOMRectReadOnly, provided by the DOMRectReadOnly$Typings extension

MDN Reference
no setter
hashCode → int
The hash code for this object.
no setterinherited
height ↔ num

Available on DOMRect, provided by the DOMRect$Typings extension

MDN Reference
getter/setter pair
height → num

Available on DOMRectReadOnly, provided by the DOMRectReadOnly$Typings extension

MDN Reference
no setter
left → num

Available on DOMRectReadOnly, provided by the DOMRectReadOnly$Typings extension

MDN Reference
no setter

Available on DOMRectReadOnly, provided by the DOMRectReadOnly$Typings extension

MDN Reference
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJSON ↔ dynamic Function()

Available on DOMRectReadOnly, provided by the DOMRectReadOnly$Typings extension

getter/setter pair
top → num

Available on DOMRectReadOnly, provided by the DOMRectReadOnly$Typings extension

MDN Reference
no setter
width ↔ num

Available on DOMRect, provided by the DOMRect$Typings extension

MDN Reference
getter/setter pair
width → num

Available on DOMRectReadOnly, provided by the DOMRectReadOnly$Typings extension

MDN Reference
no setter
x ↔ num

Available on DOMRect, provided by the DOMRect$Typings extension

MDN Reference
getter/setter pair
x → num

Available on DOMRectReadOnly, provided by the DOMRectReadOnly$Typings extension

MDN Reference
no setter
y ↔ num

Available on DOMRect, provided by the DOMRect$Typings extension

MDN Reference
getter/setter pair
y → num

Available on DOMRectReadOnly, provided by the DOMRectReadOnly$Typings extension

MDN Reference
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

fromRect ↔ DOMRect Function([DOMRectInit?])
getter/setter pair