DateTimeFormatOptions class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

DateTimeFormatOptions({LocaleMatcherOptions? localeMatcher, Weekday? weekday, Era? era, Year? year, Month? month, Day? day, Hour? hour, Minute? minute, Second? second, TimeZoneName? timeZoneName, FormatMatcher? formatMatcher, bool? hour12, String? timeZone, String? calendar, DayPeriod? dayPeriod, String? numberingSystem, DateStyle? dateStyle, TimeStyle? timeStyle, HourCycle? hourCycle, FractionalSecondDigits? fractionalSecondDigits})
factory

Properties

calendar ↔ String?

Available on DateTimeFormatOptions, provided by the DateTimeFormatOptions$Typings extension

getter/setter pair
dateStyle ↔ DateStyle?

Available on DateTimeFormatOptions, provided by the DateTimeFormatOptions$Typings extension

getter/setter pair
day ↔ Day?

Available on DateTimeFormatOptions, provided by the DateTimeFormatOptions$Typings extension

getter/setter pair
dayPeriod ↔ DayPeriod?

Available on DateTimeFormatOptions, provided by the DateTimeFormatOptions$Typings extension

getter/setter pair
era ↔ Era?

Available on DateTimeFormatOptions, provided by the DateTimeFormatOptions$Typings extension

getter/setter pair
formatMatcher ↔ FormatMatcher?

Available on DateTimeFormatOptions, provided by the DateTimeFormatOptions$Typings extension

getter/setter pair
fractionalSecondDigits ↔ FractionalSecondDigits?

Available on DateTimeFormatOptions, provided by the DateTimeFormatOptions$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hour ↔ Hour?

Available on DateTimeFormatOptions, provided by the DateTimeFormatOptions$Typings extension

getter/setter pair
hour12 ↔ bool?

Available on DateTimeFormatOptions, provided by the DateTimeFormatOptions$Typings extension

getter/setter pair
hourCycle ↔ HourCycle?

Available on DateTimeFormatOptions, provided by the DateTimeFormatOptions$Typings extension

getter/setter pair
localeMatcher ↔ LocaleMatcherOptions?

Available on DateTimeFormatOptions, provided by the DateTimeFormatOptions$Typings extension

getter/setter pair
minute ↔ Minute?

Available on DateTimeFormatOptions, provided by the DateTimeFormatOptions$Typings extension

getter/setter pair
month ↔ Month?

Available on DateTimeFormatOptions, provided by the DateTimeFormatOptions$Typings extension

getter/setter pair
numberingSystem ↔ String?

Available on DateTimeFormatOptions, provided by the DateTimeFormatOptions$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
second ↔ Second?

Available on DateTimeFormatOptions, provided by the DateTimeFormatOptions$Typings extension

getter/setter pair
timeStyle ↔ TimeStyle?

Available on DateTimeFormatOptions, provided by the DateTimeFormatOptions$Typings extension

getter/setter pair
timeZone ↔ String?

Available on DateTimeFormatOptions, provided by the DateTimeFormatOptions$Typings extension

getter/setter pair
timeZoneName ↔ TimeZoneName?

Available on DateTimeFormatOptions, provided by the DateTimeFormatOptions$Typings extension

getter/setter pair
weekday ↔ Weekday?

Available on DateTimeFormatOptions, provided by the DateTimeFormatOptions$Typings extension

getter/setter pair
year ↔ Year?

Available on DateTimeFormatOptions, provided by the DateTimeFormatOptions$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited