DisplayNamesOptions class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Properties

fallback ↔ DisplayNamesFallback?

Available on DisplayNamesOptions, provided by the DisplayNamesOptions$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
languageDisplay ↔ DisplayNamesLanguageDisplay?

Available on DisplayNamesOptions, provided by the DisplayNamesOptions$Typings extension

getter/setter pair
localeMatcher ↔ RelativeTimeFormatLocaleMatcher?

Available on DisplayNamesOptions, provided by the DisplayNamesOptions$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style ↔ RelativeTimeFormatStyle?

Available on DisplayNamesOptions, provided by the DisplayNamesOptions$Typings extension

getter/setter pair
type ↔ DisplayNamesType

Available on DisplayNamesOptions, provided by the DisplayNamesOptions$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited