DynamicsCompressorOptions class

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

DynamicsCompressorOptions({num? attack, num? knee, num? ratio, num? release, num? threshold, num? channelCount, ChannelCountMode? channelCountMode, ChannelInterpretation? channelInterpretation})
factory

Properties

attack ↔ num?

Available on DynamicsCompressorOptions, provided by the DynamicsCompressorOptions$Typings extension

getter/setter pair
channelCount ↔ num?

Available on AudioNodeOptions, provided by the AudioNodeOptions$Typings extension

getter/setter pair
channelCountMode ↔ ChannelCountMode?

Available on AudioNodeOptions, provided by the AudioNodeOptions$Typings extension

getter/setter pair
channelInterpretation ↔ ChannelInterpretation?

Available on AudioNodeOptions, provided by the AudioNodeOptions$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
knee ↔ num?

Available on DynamicsCompressorOptions, provided by the DynamicsCompressorOptions$Typings extension

getter/setter pair
ratio ↔ num?

Available on DynamicsCompressorOptions, provided by the DynamicsCompressorOptions$Typings extension

getter/setter pair
release ↔ num?

Available on DynamicsCompressorOptions, provided by the DynamicsCompressorOptions$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threshold ↔ num?

Available on DynamicsCompressorOptions, provided by the DynamicsCompressorOptions$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited