EcKeyAlgorithm class

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

EcKeyAlgorithm({String? namedCurve, String? name})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String

Available on KeyAlgorithm, provided by the KeyAlgorithm$Typings extension

getter/setter pair
namedCurve ↔ String

Available on EcKeyAlgorithm, provided by the EcKeyAlgorithm$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited