EffectAllowed enum
Values
- none → const EffectAllowed
-
const EffectAllowed(r'none') - copy → const EffectAllowed
-
const EffectAllowed(r'copy') - copyLink → const EffectAllowed
-
const EffectAllowed(r'copyLink') - copyMove → const EffectAllowed
-
const EffectAllowed(r'copyMove') - link → const EffectAllowed
-
const EffectAllowed(r'link') - linkMove → const EffectAllowed
-
const EffectAllowed(r'linkMove') - move → const EffectAllowed
-
const EffectAllowed(r'move') - all → const EffectAllowed
-
const EffectAllowed(r'all') - uninitialized → const EffectAllowed
-
const EffectAllowed(r'uninitialized')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
EffectAllowed> - A constant List of the values in this enum, in order of their declaration.