ElementInternals$Typings extension

on

Properties

checkValidity ↔ bool Function()

Available on ElementInternals, provided by the ElementInternals$Typings extension

getter/setter pair
form → HTMLFormElement?

Available on ElementInternals, provided by the ElementInternals$Typings extension

Returns the form owner of internals's target element.
no setter
labels → NodeList

Available on ElementInternals, provided by the ElementInternals$Typings extension

Returns a NodeList of all the label elements that internals's target element is associated with.
no setter
reportValidity ↔ bool Function()

Available on ElementInternals, provided by the ElementInternals$Typings extension

getter/setter pair
setFormValue ↔ void Function([dynamic, dynamic])

Available on ElementInternals, provided by the ElementInternals$Typings extension

getter/setter pair
setValidity ↔ void Function([ValidityStateFlags?, String?, HTMLElement?])

Available on ElementInternals, provided by the ElementInternals$Typings extension

getter/setter pair
shadowRoot → ShadowRoot?

Available on ElementInternals, provided by the ElementInternals$Typings extension

Returns the ShadowRoot for internals's target element, if the target element is a shadow host, or null otherwise.
no setter
validationMessage → String

Available on ElementInternals, provided by the ElementInternals$Typings extension

Returns the error message that would be shown to the user if internals's target element was to be checked for validity.
no setter
validity → ValidityState

Available on ElementInternals, provided by the ElementInternals$Typings extension

Returns the ValidityState object for internals's target element.
no setter
willValidate → bool

Available on ElementInternals, provided by the ElementInternals$Typings extension

Returns true if internals's target element will be validated when the form is submitted; false otherwise.
no setter