FileList class

An object of this type is returned by the files property of the HTML element; this lets you access the list of files selected with the element. It's also used for a list of files dropped into web content when using the drag and drop API; see the DataTransfer object for details on this usage.

MDN Reference

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

FileList()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
item ↔ File? Function(num)

Available on FileList, provided by the FileList$Typings extension

getter/setter pair
length → num

Available on FileList, provided by the FileList$Typings extension

MDN Reference
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](num index) → File

Available on FileList, provided by the FileList$Typings extension

operator []=(num index, File value) → void

Available on FileList, provided by the FileList$Typings extension