FileSystemWritableFileStream class

Available only in secure contexts.

MDN Reference

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

FileSystemWritableFileStream()
factory

Properties

abort ↔ Future<void> Function([dynamic])

Available on WritableStream<W>, provided by the WritableStream$Typings extension

getter/setter pair
close ↔ Future<void> Function()

Available on WritableStream<W>, provided by the WritableStream$Typings extension

getter/setter pair
getWriter ↔ WritableStreamDefaultWriter<W> Function()

Available on WritableStream<W>, provided by the WritableStream$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
locked → bool

Available on WritableStream<W>, provided by the WritableStream$Typings extension

MDN Reference
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seek ↔ Future<void> Function(num)

Available on FileSystemWritableFileStream, provided by the FileSystemWritableFileStream$Typings extension

getter/setter pair
truncate ↔ Future<void> Function(num)

Available on FileSystemWritableFileStream, provided by the FileSystemWritableFileStream$Typings extension

getter/setter pair
write ↔ Future<void> Function(Object)

Available on FileSystemWritableFileStream, provided by the FileSystemWritableFileStream$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited