GeolocationPositionError class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

GeolocationPositionError()
factory

Properties

code → num

Available on GeolocationPositionError, provided by the GeolocationPositionError$Typings extension

MDN Reference
no setter
hashCode → int
The hash code for this object.
no setterinherited
message → String

Available on GeolocationPositionError, provided by the GeolocationPositionError$Typings extension

MDN Reference
no setter
permissionDenied → num

Available on GeolocationPositionError, provided by the GeolocationPositionError$Typings extension

no setter
positionUnavailable → num

Available on GeolocationPositionError, provided by the GeolocationPositionError$Typings extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeout → num

Available on GeolocationPositionError, provided by the GeolocationPositionError$Typings extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

permissionDenied → num
no setter
positionUnavailable → num
no setter
timeout → num
no setter