HTMLAllCollection class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

HTMLAllCollection()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
item ↔ dynamic Function([String?])

Available on HTMLAllCollection, provided by the HTMLAllCollection$Typings extension

getter/setter pair
length → num

Available on HTMLAllCollection, provided by the HTMLAllCollection$Typings extension

Returns the number of elements in the collection.
no setter
namedItem ↔ dynamic Function(String index)

Available on HTMLAllCollection, provided by the HTMLAllCollection$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](num index) → Element

Available on HTMLAllCollection, provided by the HTMLAllCollection$Typings extension

operator []=(num index, Element value) → void

Available on HTMLAllCollection, provided by the HTMLAllCollection$Typings extension