HTMLCollection class

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

HTMLCollection()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
item ↔ Element? Function(num)

Available on HTMLCollectionBase, provided by the HTMLCollectionBase$Typings extension

getter/setter pair
length → num

Available on HTMLCollectionBase, provided by the HTMLCollectionBase$Typings extension

Sets or retrieves the number of objects in a collection.
no setter
namedItem ↔ Element? Function(String)

Available on HTMLCollection, provided by the HTMLCollection$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](num index) → Element

Available on HTMLCollectionBase, provided by the HTMLCollectionBase$Typings extension

operator []=(num index, Element value) → void

Available on HTMLCollectionBase, provided by the HTMLCollectionBase$Typings extension