HTMLFormElement$Typings extension

on

Properties

acceptCharset ↔ String

Available on HTMLFormElement, provided by the HTMLFormElement$Typings extension

Sets or retrieves a list of character encodings for input data that must be accepted by the server processing the form.
getter/setter pair
action ↔ String

Available on HTMLFormElement, provided by the HTMLFormElement$Typings extension

Sets or retrieves the URL to which the form content is sent for processing.
getter/setter pair
addEventListener → ({void Function<K$>(HTMLElementEventMap<K$> type, dynamic listener(K$), [Object? options]) $1, void Function(String type, Object listener, [Object? options]) $2})

Available on HTMLFormElement, provided by the HTMLFormElement$Typings extension

Overload accessor: $1, $2
no setter
autocomplete ↔ AutoFillBase

Available on HTMLFormElement, provided by the HTMLFormElement$Typings extension

Specifies whether autocomplete is applied to an editable text field.
getter/setter pair
checkValidity ↔ bool Function()

Available on HTMLFormElement, provided by the HTMLFormElement$Typings extension

getter/setter pair
elements → HTMLFormControlsCollection

Available on HTMLFormElement, provided by the HTMLFormElement$Typings extension

Retrieves a collection, in source order, of all controls in a given form.
no setter
encoding ↔ String

Available on HTMLFormElement, provided by the HTMLFormElement$Typings extension

Sets or retrieves the MIME encoding for the form.
getter/setter pair
enctype ↔ String

Available on HTMLFormElement, provided by the HTMLFormElement$Typings extension

Sets or retrieves the encoding type for the form.
getter/setter pair
length → num

Available on HTMLFormElement, provided by the HTMLFormElement$Typings extension

Sets or retrieves the number of objects in a collection.
no setter
method ↔ String

Available on HTMLFormElement, provided by the HTMLFormElement$Typings extension

Sets or retrieves how to send the form data to the server.
getter/setter pair
name ↔ String

Available on HTMLFormElement, provided by the HTMLFormElement$Typings extension

Sets or retrieves the name of the object.
getter/setter pair
noValidate ↔ bool

Available on HTMLFormElement, provided by the HTMLFormElement$Typings extension

Designates a form that is not validated when submitted.
getter/setter pair
rel ↔ String

Available on HTMLFormElement, provided by the HTMLFormElement$Typings extension

getter/setter pair
relList → DOMTokenList

Available on HTMLFormElement, provided by the HTMLFormElement$Typings extension

no setter
removeEventListener → ({void Function<K$>(HTMLElementEventMap<K$> type, dynamic listener(K$), [Object? options]) $1, void Function(String type, Object listener, [Object? options]) $2})

Available on HTMLFormElement, provided by the HTMLFormElement$Typings extension

Overload accessor: $1, $2
no setter
reportValidity ↔ bool Function()

Available on HTMLFormElement, provided by the HTMLFormElement$Typings extension

getter/setter pair
requestSubmit ↔ void Function([HTMLElement?])

Available on HTMLFormElement, provided by the HTMLFormElement$Typings extension

getter/setter pair
reset ↔ void Function()

Available on HTMLFormElement, provided by the HTMLFormElement$Typings extension

getter/setter pair
submit ↔ void Function()

Available on HTMLFormElement, provided by the HTMLFormElement$Typings extension

getter/setter pair
target ↔ String

Available on HTMLFormElement, provided by the HTMLFormElement$Typings extension

Sets or retrieves the window or frame at which to target content.
getter/setter pair

Operators

operator [](num index) → Element

Available on HTMLFormElement, provided by the HTMLFormElement$Typings extension

operator []=(num index, Element value) → void

Available on HTMLFormElement, provided by the HTMLFormElement$Typings extension