HTMLHyperlinkElementUtils class

Implementers
Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

HTMLHyperlinkElementUtils({String? hash, String? host, String? hostname, String? href, String? origin, String? password, String? pathname, String? port, String? protocol, String? search, String? username, String toString$()?})
factory

Properties

hash ↔ String

Available on HTMLHyperlinkElementUtils, provided by the HTMLHyperlinkElementUtils$Typings extension

Returns the hyperlink's URL's fragment (includes leading "#" if non-empty).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
host ↔ String

Available on HTMLHyperlinkElementUtils, provided by the HTMLHyperlinkElementUtils$Typings extension

Returns the hyperlink's URL's host and port (if different from the default port for the scheme).
getter/setter pair
hostname ↔ String

Available on HTMLHyperlinkElementUtils, provided by the HTMLHyperlinkElementUtils$Typings extension

Returns the hyperlink's URL's host.
getter/setter pair
href ↔ String

Available on HTMLHyperlinkElementUtils, provided by the HTMLHyperlinkElementUtils$Typings extension

Returns the hyperlink's URL.
getter/setter pair
origin → String

Available on HTMLHyperlinkElementUtils, provided by the HTMLHyperlinkElementUtils$Typings extension

Returns the hyperlink's URL's origin.
no setter
password ↔ String

Available on HTMLHyperlinkElementUtils, provided by the HTMLHyperlinkElementUtils$Typings extension

Returns the hyperlink's URL's password.
getter/setter pair
pathname ↔ String

Available on HTMLHyperlinkElementUtils, provided by the HTMLHyperlinkElementUtils$Typings extension

Returns the hyperlink's URL's path.
getter/setter pair
port ↔ String

Available on HTMLHyperlinkElementUtils, provided by the HTMLHyperlinkElementUtils$Typings extension

Returns the hyperlink's URL's port.
getter/setter pair
protocol ↔ String

Available on HTMLHyperlinkElementUtils, provided by the HTMLHyperlinkElementUtils$Typings extension

Returns the hyperlink's URL's scheme.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Available on HTMLHyperlinkElementUtils, provided by the HTMLHyperlinkElementUtils$Typings extension

Returns the hyperlink's URL's query (includes leading "?" if non-empty).
getter/setter pair
toString$ ↔ String Function()

Available on HTMLHyperlinkElementUtils, provided by the HTMLHyperlinkElementUtils$Typings extension

getter/setter pair
username ↔ String

Available on HTMLHyperlinkElementUtils, provided by the HTMLHyperlinkElementUtils$Typings extension

Returns the hyperlink's URL's username.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited