HTMLIFrameElement$Typings extension

on

Properties

addEventListener → ({void Function<K$>(HTMLElementEventMap<K$> type, dynamic listener(K$), [Object? options]) $1, void Function(String type, Object listener, [Object? options]) $2})

Available on HTMLIFrameElement, provided by the HTMLIFrameElement$Typings extension

Overload accessor: $1, $2
no setter
align ↔ String

Available on HTMLIFrameElement, provided by the HTMLIFrameElement$Typings extension

Sets or retrieves how the object is aligned with adjacent text. @deprecated
getter/setter pair
allow ↔ String

Available on HTMLIFrameElement, provided by the HTMLIFrameElement$Typings extension

getter/setter pair
allowFullscreen ↔ bool

Available on HTMLIFrameElement, provided by the HTMLIFrameElement$Typings extension

getter/setter pair
contentDocument → Document?

Available on HTMLIFrameElement, provided by the HTMLIFrameElement$Typings extension

Retrieves the document object of the page or frame.
no setter
contentWindow → Window?

Available on HTMLIFrameElement, provided by the HTMLIFrameElement$Typings extension

Retrieves the object of the specified.
no setter
frameBorder ↔ String

Available on HTMLIFrameElement, provided by the HTMLIFrameElement$Typings extension

Sets or retrieves whether to display a border for the frame. @deprecated
getter/setter pair
getSVGDocument ↔ Document? Function()

Available on HTMLIFrameElement, provided by the HTMLIFrameElement$Typings extension

getter/setter pair
height ↔ String

Available on HTMLIFrameElement, provided by the HTMLIFrameElement$Typings extension

Sets or retrieves the height of the object.
getter/setter pair
loading ↔ String

Available on HTMLIFrameElement, provided by the HTMLIFrameElement$Typings extension

getter/setter pair
longDesc ↔ String

Available on HTMLIFrameElement, provided by the HTMLIFrameElement$Typings extension

Sets or retrieves a URI to a long description of the object. @deprecated
getter/setter pair
marginHeight ↔ String

Available on HTMLIFrameElement, provided by the HTMLIFrameElement$Typings extension

Sets or retrieves the top and bottom margin heights before displaying the text in a frame. @deprecated
getter/setter pair
marginWidth ↔ String

Available on HTMLIFrameElement, provided by the HTMLIFrameElement$Typings extension

Sets or retrieves the left and right margin widths before displaying the text in a frame. @deprecated
getter/setter pair
name ↔ String

Available on HTMLIFrameElement, provided by the HTMLIFrameElement$Typings extension

Sets or retrieves the frame name.
getter/setter pair
referrerPolicy ↔ ReferrerPolicy

Available on HTMLIFrameElement, provided by the HTMLIFrameElement$Typings extension

MDN Reference
getter/setter pair
removeEventListener → ({void Function<K$>(HTMLElementEventMap<K$> type, dynamic listener(K$), [Object? options]) $1, void Function(String type, Object listener, [Object? options]) $2})

Available on HTMLIFrameElement, provided by the HTMLIFrameElement$Typings extension

Overload accessor: $1, $2
no setter
sandbox → DOMTokenList

Available on HTMLIFrameElement, provided by the HTMLIFrameElement$Typings extension

no setter
scrolling ↔ String

Available on HTMLIFrameElement, provided by the HTMLIFrameElement$Typings extension

Sets or retrieves whether the frame can be scrolled. @deprecated
getter/setter pair
src ↔ String

Available on HTMLIFrameElement, provided by the HTMLIFrameElement$Typings extension

Sets or retrieves a URL to be loaded by the object.
getter/setter pair
srcdoc ↔ String

Available on HTMLIFrameElement, provided by the HTMLIFrameElement$Typings extension

Sets or retrives the content of the page that is to contain.
getter/setter pair
width ↔ String

Available on HTMLIFrameElement, provided by the HTMLIFrameElement$Typings extension

Sets or retrieves the width of the object.
getter/setter pair