HTMLOptionElement$Typings extension

on

Properties

addEventListener → ({void Function<K$>(HTMLElementEventMap<K$> type, dynamic listener(K$), [Object? options]) $1, void Function(String type, Object listener, [Object? options]) $2})

Available on HTMLOptionElement, provided by the HTMLOptionElement$Typings extension

Overload accessor: $1, $2
no setter
defaultSelected ↔ bool

Available on HTMLOptionElement, provided by the HTMLOptionElement$Typings extension

Sets or retrieves the status of an option.
getter/setter pair
disabled ↔ bool

Available on HTMLOptionElement, provided by the HTMLOptionElement$Typings extension

MDN Reference
getter/setter pair
form → HTMLFormElement?

Available on HTMLOptionElement, provided by the HTMLOptionElement$Typings extension

Retrieves a reference to the form that the object is embedded in.
no setter
index → num

Available on HTMLOptionElement, provided by the HTMLOptionElement$Typings extension

Sets or retrieves the ordinal position of an option in a list box.
no setter
label ↔ String

Available on HTMLOptionElement, provided by the HTMLOptionElement$Typings extension

Sets or retrieves a value that you can use to implement your own label functionality for the object.
getter/setter pair
removeEventListener → ({void Function<K$>(HTMLElementEventMap<K$> type, dynamic listener(K$), [Object? options]) $1, void Function(String type, Object listener, [Object? options]) $2})

Available on HTMLOptionElement, provided by the HTMLOptionElement$Typings extension

Overload accessor: $1, $2
no setter
selected ↔ bool

Available on HTMLOptionElement, provided by the HTMLOptionElement$Typings extension

Sets or retrieves whether the option in the list box is the default item.
getter/setter pair
text ↔ String

Available on HTMLOptionElement, provided by the HTMLOptionElement$Typings extension

Sets or retrieves the text string specified by the option tag.
getter/setter pair
value ↔ String

Available on HTMLOptionElement, provided by the HTMLOptionElement$Typings extension

Sets or retrieves the value which is returned to the server when the form control is submitted.
getter/setter pair