HTMLTableCellElement$Typings extension

on

Properties

abbr ↔ String

Available on HTMLTableCellElement, provided by the HTMLTableCellElement$Typings extension

Sets or retrieves abbreviated text for the object.
getter/setter pair
addEventListener → ({void Function<K$>(HTMLElementEventMap<K$> type, dynamic listener(K$), [Object? options]) $1, void Function(String type, Object listener, [Object? options]) $2})

Available on HTMLTableCellElement, provided by the HTMLTableCellElement$Typings extension

Overload accessor: $1, $2
no setter
align ↔ String

Available on HTMLTableCellElement, provided by the HTMLTableCellElement$Typings extension

Sets or retrieves how the object is aligned with adjacent text. @deprecated
getter/setter pair
axis ↔ String

Available on HTMLTableCellElement, provided by the HTMLTableCellElement$Typings extension

Sets or retrieves a comma-delimited list of conceptual categories associated with the object. @deprecated
getter/setter pair
bgColor ↔ String

Available on HTMLTableCellElement, provided by the HTMLTableCellElement$Typings extension

@deprecated
getter/setter pair
cellIndex → num

Available on HTMLTableCellElement, provided by the HTMLTableCellElement$Typings extension

Retrieves the position of the object in the cells collection of a row.
no setter
ch ↔ String

Available on HTMLTableCellElement, provided by the HTMLTableCellElement$Typings extension

@deprecated
getter/setter pair
chOff ↔ String

Available on HTMLTableCellElement, provided by the HTMLTableCellElement$Typings extension

@deprecated
getter/setter pair
colSpan ↔ num

Available on HTMLTableCellElement, provided by the HTMLTableCellElement$Typings extension

Sets or retrieves the number columns in the table that the object should span.
getter/setter pair
headers ↔ String

Available on HTMLTableCellElement, provided by the HTMLTableCellElement$Typings extension

Sets or retrieves a list of header cells that provide information for the object.
getter/setter pair
height ↔ String

Available on HTMLTableCellElement, provided by the HTMLTableCellElement$Typings extension

Sets or retrieves the height of the object. @deprecated
getter/setter pair
noWrap ↔ bool

Available on HTMLTableCellElement, provided by the HTMLTableCellElement$Typings extension

Sets or retrieves whether the browser automatically performs wordwrap. @deprecated
getter/setter pair
removeEventListener → ({void Function<K$>(HTMLElementEventMap<K$> type, dynamic listener(K$), [Object? options]) $1, void Function(String type, Object listener, [Object? options]) $2})

Available on HTMLTableCellElement, provided by the HTMLTableCellElement$Typings extension

Overload accessor: $1, $2
no setter
rowSpan ↔ num

Available on HTMLTableCellElement, provided by the HTMLTableCellElement$Typings extension

Sets or retrieves how many rows in a table the cell should span.
getter/setter pair
scope ↔ String

Available on HTMLTableCellElement, provided by the HTMLTableCellElement$Typings extension

Sets or retrieves the group of cells in a table to which the object's information applies.
getter/setter pair
vAlign ↔ String

Available on HTMLTableCellElement, provided by the HTMLTableCellElement$Typings extension

@deprecated
getter/setter pair
width ↔ String

Available on HTMLTableCellElement, provided by the HTMLTableCellElement$Typings extension

Sets or retrieves the width of the object. @deprecated
getter/setter pair