HTMLTableElement$Typings extension

on

Properties

addEventListener → ({void Function<K$>(HTMLElementEventMap<K$> type, dynamic listener(K$), [Object? options]) $1, void Function(String type, Object listener, [Object? options]) $2})

Available on HTMLTableElement, provided by the HTMLTableElement$Typings extension

Overload accessor: $1, $2
no setter
align ↔ String

Available on HTMLTableElement, provided by the HTMLTableElement$Typings extension

Sets or retrieves a value that indicates the table alignment. @deprecated
getter/setter pair
bgColor ↔ String

Available on HTMLTableElement, provided by the HTMLTableElement$Typings extension

@deprecated
getter/setter pair
border ↔ String

Available on HTMLTableElement, provided by the HTMLTableElement$Typings extension

Sets or retrieves the width of the border to draw around the object. @deprecated
getter/setter pair
caption ↔ HTMLTableCaptionElement?

Available on HTMLTableElement, provided by the HTMLTableElement$Typings extension

Retrieves the caption object of a table.
getter/setter pair
cellPadding ↔ String

Available on HTMLTableElement, provided by the HTMLTableElement$Typings extension

Sets or retrieves the amount of space between the border of the cell and the content of the cell. @deprecated
getter/setter pair
cellSpacing ↔ String

Available on HTMLTableElement, provided by the HTMLTableElement$Typings extension

Sets or retrieves the amount of space between cells in a table. @deprecated
getter/setter pair
createCaption ↔ HTMLTableCaptionElement Function()

Available on HTMLTableElement, provided by the HTMLTableElement$Typings extension

getter/setter pair
createTBody ↔ HTMLTableSectionElement Function()

Available on HTMLTableElement, provided by the HTMLTableElement$Typings extension

getter/setter pair
createTFoot ↔ HTMLTableSectionElement Function()

Available on HTMLTableElement, provided by the HTMLTableElement$Typings extension

getter/setter pair
createTHead ↔ HTMLTableSectionElement Function()

Available on HTMLTableElement, provided by the HTMLTableElement$Typings extension

getter/setter pair
deleteCaption ↔ void Function()

Available on HTMLTableElement, provided by the HTMLTableElement$Typings extension

getter/setter pair
deleteRow ↔ void Function(num handle)

Available on HTMLTableElement, provided by the HTMLTableElement$Typings extension

getter/setter pair
deleteTFoot ↔ void Function()

Available on HTMLTableElement, provided by the HTMLTableElement$Typings extension

getter/setter pair
deleteTHead ↔ void Function()

Available on HTMLTableElement, provided by the HTMLTableElement$Typings extension

getter/setter pair
frame ↔ String

Available on HTMLTableElement, provided by the HTMLTableElement$Typings extension

Sets or retrieves the way the border frame around the table is displayed. @deprecated
getter/setter pair
insertRow ↔ HTMLTableRowElement Function([num?])

Available on HTMLTableElement, provided by the HTMLTableElement$Typings extension

getter/setter pair
removeEventListener → ({void Function<K$>(HTMLElementEventMap<K$> type, dynamic listener(K$), [Object? options]) $1, void Function(String type, Object listener, [Object? options]) $2})

Available on HTMLTableElement, provided by the HTMLTableElement$Typings extension

Overload accessor: $1, $2
no setter
rows → HTMLCollectionOf<HTMLTableRowElement>

Available on HTMLTableElement, provided by the HTMLTableElement$Typings extension

Sets or retrieves the number of horizontal rows contained in the object.
no setter
rules ↔ String

Available on HTMLTableElement, provided by the HTMLTableElement$Typings extension

Sets or retrieves which dividing lines (inner borders) are displayed. @deprecated
getter/setter pair
summary ↔ String

Available on HTMLTableElement, provided by the HTMLTableElement$Typings extension

Sets or retrieves a description and/or structure of the object. @deprecated
getter/setter pair
tBodies → HTMLCollectionOf<HTMLTableSectionElement>

Available on HTMLTableElement, provided by the HTMLTableElement$Typings extension

Retrieves a collection of all tBody objects in the table. Objects in this collection are in source order.
no setter
tFoot ↔ HTMLTableSectionElement?

Available on HTMLTableElement, provided by the HTMLTableElement$Typings extension

Retrieves the tFoot object of the table.
getter/setter pair
tHead ↔ HTMLTableSectionElement?

Available on HTMLTableElement, provided by the HTMLTableElement$Typings extension

Retrieves the tHead object of the table.
getter/setter pair
width ↔ String

Available on HTMLTableElement, provided by the HTMLTableElement$Typings extension

Sets or retrieves the width of the object. @deprecated
getter/setter pair