HTMLTableRowElement$Typings extension

on

Properties

addEventListener → ({void Function<K$>(HTMLElementEventMap<K$> type, dynamic listener(K$), [Object? options]) $1, void Function(String type, Object listener, [Object? options]) $2})

Available on HTMLTableRowElement, provided by the HTMLTableRowElement$Typings extension

Overload accessor: $1, $2
no setter
align ↔ String

Available on HTMLTableRowElement, provided by the HTMLTableRowElement$Typings extension

Sets or retrieves how the object is aligned with adjacent text. @deprecated
getter/setter pair
bgColor ↔ String

Available on HTMLTableRowElement, provided by the HTMLTableRowElement$Typings extension

@deprecated
getter/setter pair
cells → HTMLCollectionOf<HTMLTableCellElement>

Available on HTMLTableRowElement, provided by the HTMLTableRowElement$Typings extension

Retrieves a collection of all cells in the table row.
no setter
ch ↔ String

Available on HTMLTableRowElement, provided by the HTMLTableRowElement$Typings extension

@deprecated
getter/setter pair
chOff ↔ String

Available on HTMLTableRowElement, provided by the HTMLTableRowElement$Typings extension

@deprecated
getter/setter pair
deleteCell ↔ void Function(num handle)

Available on HTMLTableRowElement, provided by the HTMLTableRowElement$Typings extension

getter/setter pair
insertCell ↔ HTMLTableCellElement Function([num?])

Available on HTMLTableRowElement, provided by the HTMLTableRowElement$Typings extension

getter/setter pair
removeEventListener → ({void Function<K$>(HTMLElementEventMap<K$> type, dynamic listener(K$), [Object? options]) $1, void Function(String type, Object listener, [Object? options]) $2})

Available on HTMLTableRowElement, provided by the HTMLTableRowElement$Typings extension

Overload accessor: $1, $2
no setter
rowIndex → num

Available on HTMLTableRowElement, provided by the HTMLTableRowElement$Typings extension

Retrieves the position of the object in the rows collection for the table.
no setter
sectionRowIndex → num

Available on HTMLTableRowElement, provided by the HTMLTableRowElement$Typings extension

Retrieves the position of the object in the collection.
no setter
vAlign ↔ String

Available on HTMLTableRowElement, provided by the HTMLTableRowElement$Typings extension

@deprecated
getter/setter pair