ImageBitmapOptions class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

ImageBitmapOptions({ColorSpaceConversion? colorSpaceConversion, ImageOrientation? imageOrientation, PremultiplyAlpha? premultiplyAlpha, num? resizeHeight, ResizeQuality? resizeQuality, num? resizeWidth})
factory

Properties

colorSpaceConversion ↔ ColorSpaceConversion?

Available on ImageBitmapOptions, provided by the ImageBitmapOptions$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageOrientation ↔ ImageOrientation?

Available on ImageBitmapOptions, provided by the ImageBitmapOptions$Typings extension

getter/setter pair
premultiplyAlpha ↔ PremultiplyAlpha?

Available on ImageBitmapOptions, provided by the ImageBitmapOptions$Typings extension

getter/setter pair
resizeHeight ↔ num?

Available on ImageBitmapOptions, provided by the ImageBitmapOptions$Typings extension

getter/setter pair
resizeQuality ↔ ResizeQuality?

Available on ImageBitmapOptions, provided by the ImageBitmapOptions$Typings extension

getter/setter pair
resizeWidth ↔ num?

Available on ImageBitmapOptions, provided by the ImageBitmapOptions$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited