IntersectionObserverEntry class

This Intersection Observer API interface describes the intersection between the target element and its root container at a specific moment of transition.

MDN Reference

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

IntersectionObserverEntry(IntersectionObserverEntryInit intersectionObserverEntryInit)
factory

Properties

boundingClientRect → DOMRectReadOnly

Available on IntersectionObserverEntry, provided by the IntersectionObserverEntry$Typings extension

MDN Reference
no setter
hashCode → int
The hash code for this object.
no setterinherited
intersectionRatio → num

Available on IntersectionObserverEntry, provided by the IntersectionObserverEntry$Typings extension

MDN Reference
no setter
intersectionRect → DOMRectReadOnly

Available on IntersectionObserverEntry, provided by the IntersectionObserverEntry$Typings extension

MDN Reference
no setter
isIntersecting → bool

Available on IntersectionObserverEntry, provided by the IntersectionObserverEntry$Typings extension

MDN Reference
no setter
rootBounds → DOMRectReadOnly?

Available on IntersectionObserverEntry, provided by the IntersectionObserverEntry$Typings extension

MDN Reference
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → Element

Available on IntersectionObserverEntry, provided by the IntersectionObserverEntry$Typings extension

MDN Reference
no setter
time → num

Available on IntersectionObserverEntry, provided by the IntersectionObserverEntry$Typings extension

MDN Reference
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited