IntersectionObserverEntryInit class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

IntersectionObserverEntryInit({DOMRectInit? boundingClientRect, num? intersectionRatio, DOMRectInit? intersectionRect, bool? isIntersecting, DOMRectInit? rootBounds, Element? target, num? time})
factory

Properties

boundingClientRect ↔ DOMRectInit

Available on IntersectionObserverEntryInit, provided by the IntersectionObserverEntryInit$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
intersectionRatio ↔ num

Available on IntersectionObserverEntryInit, provided by the IntersectionObserverEntryInit$Typings extension

getter/setter pair
intersectionRect ↔ DOMRectInit

Available on IntersectionObserverEntryInit, provided by the IntersectionObserverEntryInit$Typings extension

getter/setter pair
isIntersecting ↔ bool

Available on IntersectionObserverEntryInit, provided by the IntersectionObserverEntryInit$Typings extension

getter/setter pair
rootBounds ↔ DOMRectInit?

Available on IntersectionObserverEntryInit, provided by the IntersectionObserverEntryInit$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target ↔ Element

Available on IntersectionObserverEntryInit, provided by the IntersectionObserverEntryInit$Typings extension

getter/setter pair
time ↔ num

Available on IntersectionObserverEntryInit, provided by the IntersectionObserverEntryInit$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited