KeyframeAnimationOptions class

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

KeyframeAnimationOptions({String? id, AnimationTimeline? timeline, CompositeOperation? composite, IterationCompositeOperation? iterationComposite, String? pseudoElement})
factory

Properties

composite ↔ CompositeOperation?

Available on KeyframeEffectOptions, provided by the KeyframeEffectOptions$Typings extension

getter/setter pair
delay ↔ num?

Available on EffectTiming, provided by the EffectTiming$Typings extension

getter/setter pair
direction ↔ PlaybackDirection?

Available on EffectTiming, provided by the EffectTiming$Typings extension

getter/setter pair
duration ↔ Object?

Available on EffectTiming, provided by the EffectTiming$Typings extension

getter/setter pair
easing ↔ String?

Available on EffectTiming, provided by the EffectTiming$Typings extension

getter/setter pair
endDelay ↔ num?

Available on EffectTiming, provided by the EffectTiming$Typings extension

getter/setter pair
fill ↔ FillMode?

Available on EffectTiming, provided by the EffectTiming$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?

Available on KeyframeAnimationOptions, provided by the KeyframeAnimationOptions$Typings extension

getter/setter pair
iterationComposite ↔ IterationCompositeOperation?

Available on KeyframeEffectOptions, provided by the KeyframeEffectOptions$Typings extension

getter/setter pair
iterations ↔ num?

Available on EffectTiming, provided by the EffectTiming$Typings extension

getter/setter pair
iterationStart ↔ num?

Available on EffectTiming, provided by the EffectTiming$Typings extension

getter/setter pair
playbackRate ↔ num?

Available on EffectTiming, provided by the EffectTiming$Typings extension

getter/setter pair
pseudoElement ↔ String?

Available on KeyframeEffectOptions, provided by the KeyframeEffectOptions$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeline ↔ AnimationTimeline?

Available on KeyframeAnimationOptions, provided by the KeyframeAnimationOptions$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited