ListFormatOptions class

An object with some or all properties of the Intl.ListFormat constructor options parameter.

MDN.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

ListFormatOptions({ListFormatLocaleMatcher? localeMatcher, ListFormatType? type, ListFormatStyle? style})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
localeMatcher ↔ ListFormatLocaleMatcher?

Available on ListFormatOptions, provided by the ListFormatOptions$Typings extension

The locale matching algorithm to use. For information about this option, see Intl page.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style ↔ ListFormatStyle?

Available on ListFormatOptions, provided by the ListFormatOptions$Typings extension

The length of the internationalized message.
getter/setter pair
type ↔ ListFormatType?

Available on ListFormatOptions, provided by the ListFormatOptions$Typings extension

The format of output message.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited