LockOptions class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

LockOptions({bool? ifAvailable, LockMode? mode, AbortSignal? signal, bool? steal})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
ifAvailable ↔ bool?

Available on LockOptions, provided by the LockOptions$Typings extension

getter/setter pair
mode ↔ LockMode?

Available on LockOptions, provided by the LockOptions$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signal ↔ AbortSignal?

Available on LockOptions, provided by the LockOptions$Typings extension

getter/setter pair
steal ↔ bool?

Available on LockOptions, provided by the LockOptions$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited