MediaCapabilitiesEncodingInfo class

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

MediaCapabilitiesEncodingInfo({MediaEncodingConfiguration? configuration, bool? powerEfficient, bool? smooth, bool? supported})
factory

Properties

configuration ↔ MediaEncodingConfiguration?

Available on MediaCapabilitiesEncodingInfo, provided by the MediaCapabilitiesEncodingInfo$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
powerEfficient ↔ bool

Available on MediaCapabilitiesInfo, provided by the MediaCapabilitiesInfo$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
smooth ↔ bool

Available on MediaCapabilitiesInfo, provided by the MediaCapabilitiesInfo$Typings extension

getter/setter pair
supported ↔ bool

Available on MediaCapabilitiesInfo, provided by the MediaCapabilitiesInfo$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited