MemoryDescriptor class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

MemoryDescriptor({num? initial, num? maximum, bool? shared})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
initial ↔ num

Available on MemoryDescriptor, provided by the MemoryDescriptor$Typings extension

getter/setter pair
maximum ↔ num?

Available on MemoryDescriptor, provided by the MemoryDescriptor$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shared ↔ bool?

Available on MemoryDescriptor, provided by the MemoryDescriptor$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited