NodeListOf<TNode extends Node> class

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

NodeListOf({dynamic item(num)?, void forEach(void (dynamic, num, NodeListOf), [dynamic])?, num? length})
factory

Properties

forEach ↔ void Function(void (Node, num, NodeList), [dynamic])

Available on NodeList, provided by the NodeList$Typings extension

getter/setter pair
forEach ↔ void Function(void (TNode, num, NodeListOf<TNode>), [dynamic])

Available on NodeListOf<TNode>, provided by the NodeListOf$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
item ↔ Node? Function(num)

Available on NodeList, provided by the NodeList$Typings extension

getter/setter pair
item ↔ TNode Function(num)

Available on NodeListOf<TNode>, provided by the NodeListOf$Typings extension

getter/setter pair
length → num

Available on NodeList, provided by the NodeList$Typings extension

Returns the number of nodes in the collection.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](num index) → Node

Available on NodeList, provided by the NodeList$Typings extension

operator [](num index) → TNode

Available on NodeListOf<TNode>, provided by the NodeListOf$Typings extension

operator []=(num index, Node value) → void

Available on NodeList, provided by the NodeList$Typings extension

operator []=(num index, TNode value) → void

Available on NodeListOf<TNode>, provided by the NodeListOf$Typings extension