NumberFormatOptions class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

NumberFormatOptions({String? localeMatcher, String? style, String? currency, String? currencySign, bool? useGrouping, num? minimumIntegerDigits, num? minimumFractionDigits, num? maximumFractionDigits, num? minimumSignificantDigits, num? maximumSignificantDigits, CompactDisplay? compactDisplay, Notation? notation, SignDisplay? signDisplay, String? unit, UnitDisplay? unitDisplay, String? currencyDisplay})
factory

Properties

compactDisplay ↔ CompactDisplay?

Available on NumberFormatOptions, provided by the NumberFormatOptions$Typings extension

getter/setter pair
currency ↔ String?

Available on NumberFormatOptions, provided by the NumberFormatOptions$Typings extension

getter/setter pair
currencyDisplay ↔ String?

Available on NumberFormatOptions, provided by the NumberFormatOptions$Typings extension

getter/setter pair
currencySign ↔ String?

Available on NumberFormatOptions, provided by the NumberFormatOptions$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
localeMatcher ↔ String?

Available on NumberFormatOptions, provided by the NumberFormatOptions$Typings extension

getter/setter pair
maximumFractionDigits ↔ num?

Available on NumberFormatOptions, provided by the NumberFormatOptions$Typings extension

getter/setter pair
maximumSignificantDigits ↔ num?

Available on NumberFormatOptions, provided by the NumberFormatOptions$Typings extension

getter/setter pair
minimumFractionDigits ↔ num?

Available on NumberFormatOptions, provided by the NumberFormatOptions$Typings extension

getter/setter pair
minimumIntegerDigits ↔ num?

Available on NumberFormatOptions, provided by the NumberFormatOptions$Typings extension

getter/setter pair
minimumSignificantDigits ↔ num?

Available on NumberFormatOptions, provided by the NumberFormatOptions$Typings extension

getter/setter pair
notation ↔ Notation?

Available on NumberFormatOptions, provided by the NumberFormatOptions$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signDisplay ↔ SignDisplay?

Available on NumberFormatOptions, provided by the NumberFormatOptions$Typings extension

getter/setter pair
style ↔ String?

Available on NumberFormatOptions, provided by the NumberFormatOptions$Typings extension

getter/setter pair
unit ↔ String?

Available on NumberFormatOptions, provided by the NumberFormatOptions$Typings extension

getter/setter pair
unitDisplay ↔ UnitDisplay?

Available on NumberFormatOptions, provided by the NumberFormatOptions$Typings extension

getter/setter pair
useGrouping ↔ bool?

Available on NumberFormatOptions, provided by the NumberFormatOptions$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited