OESVertexArrayObject class

Available extensions
Annotations
  • @JS.new('OES_vertex_array_object')
  • @staticInterop
  • @anonymous

Constructors

OESVertexArrayObject({num? vertexArrayBindingOes, void bindVertexArrayOES([WebGLVertexArrayObjectOES?])?, WebGLVertexArrayObjectOES? createVertexArrayOES()?, void deleteVertexArrayOES([WebGLVertexArrayObjectOES?])?, bool isVertexArrayOES([WebGLVertexArrayObjectOES?])?})
factory

Properties

bindVertexArrayOES ↔ void Function([WebGLVertexArrayObjectOES?])

Available on OESVertexArrayObject, provided by the OESVertexArrayObject$Typings extension

getter/setter pair
createVertexArrayOES ↔ WebGLVertexArrayObjectOES? Function()

Available on OESVertexArrayObject, provided by the OESVertexArrayObject$Typings extension

getter/setter pair
deleteVertexArrayOES ↔ void Function([WebGLVertexArrayObjectOES?])

Available on OESVertexArrayObject, provided by the OESVertexArrayObject$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isVertexArrayOES ↔ bool Function([WebGLVertexArrayObjectOES?])

Available on OESVertexArrayObject, provided by the OESVertexArrayObject$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vertexArrayBindingOes → num

Available on OESVertexArrayObject, provided by the OESVertexArrayObject$Typings extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

vertexArrayBindingOes → num
no setter