PerformanceMeasureOptions class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

PerformanceMeasureOptions({dynamic detail, num? duration, Object? end, Object? start})
factory

Properties

detail ↔ dynamic

Available on PerformanceMeasureOptions, provided by the PerformanceMeasureOptions$Typings extension

getter/setter pair
duration ↔ num?

Available on PerformanceMeasureOptions, provided by the PerformanceMeasureOptions$Typings extension

getter/setter pair
end ↔ Object?

Available on PerformanceMeasureOptions, provided by the PerformanceMeasureOptions$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start ↔ Object?

Available on PerformanceMeasureOptions, provided by the PerformanceMeasureOptions$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited