PerformanceNavigation class

The legacy PerformanceNavigation interface represents information about how the navigation to the current document was done.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

PerformanceNavigation()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
redirectCount → num

Available on PerformanceNavigation, provided by the PerformanceNavigation$Typings extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJSON ↔ dynamic Function()

Available on PerformanceNavigation, provided by the PerformanceNavigation$Typings extension

getter/setter pair
type → num

Available on PerformanceNavigation, provided by the PerformanceNavigation$Typings extension

no setter
typeBackForward → num

Available on PerformanceNavigation, provided by the PerformanceNavigation$Typings extension

no setter
typeNavigate → num

Available on PerformanceNavigation, provided by the PerformanceNavigation$Typings extension

no setter
typeReload → num

Available on PerformanceNavigation, provided by the PerformanceNavigation$Typings extension

no setter
typeReserved → num

Available on PerformanceNavigation, provided by the PerformanceNavigation$Typings extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

typeBackForward → num
no setter
typeNavigate → num
no setter
typeReload → num
no setter
typeReserved → num
no setter