PushSubscriptionOptions class

Available only in secure contexts.

MDN Reference

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

PushSubscriptionOptions()
factory

Properties

applicationServerKey → ByteBuffer?

Available on PushSubscriptionOptions, provided by the PushSubscriptionOptions$Typings extension

MDN Reference
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userVisibleOnly → bool

Available on PushSubscriptionOptions, provided by the PushSubscriptionOptions$Typings extension

MDN Reference
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited