RTCEncodedVideoFrameMetadata class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

RTCEncodedVideoFrameMetadata({List<num>? dependencies, num? frameId, num? height, num? spatialIndex, num? synchronizationSource, num? temporalIndex, num? width})
factory

Properties

dependencies ↔ List<num>?

Available on RTCEncodedVideoFrameMetadata, provided by the RTCEncodedVideoFrameMetadata$Typings extension

getter/setter pair
frameId ↔ num?

Available on RTCEncodedVideoFrameMetadata, provided by the RTCEncodedVideoFrameMetadata$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ num?

Available on RTCEncodedVideoFrameMetadata, provided by the RTCEncodedVideoFrameMetadata$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spatialIndex ↔ num?

Available on RTCEncodedVideoFrameMetadata, provided by the RTCEncodedVideoFrameMetadata$Typings extension

getter/setter pair
synchronizationSource ↔ num?

Available on RTCEncodedVideoFrameMetadata, provided by the RTCEncodedVideoFrameMetadata$Typings extension

getter/setter pair
temporalIndex ↔ num?

Available on RTCEncodedVideoFrameMetadata, provided by the RTCEncodedVideoFrameMetadata$Typings extension

getter/setter pair
width ↔ num?

Available on RTCEncodedVideoFrameMetadata, provided by the RTCEncodedVideoFrameMetadata$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited