RTCErrorInit class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

RTCErrorInit({RTCErrorDetailType? errorDetail, num? httpRequestStatusCode, num? receivedAlert, num? sctpCauseCode, num? sdpLineNumber, num? sentAlert})
factory

Properties

errorDetail ↔ RTCErrorDetailType

Available on RTCErrorInit, provided by the RTCErrorInit$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
httpRequestStatusCode ↔ num?

Available on RTCErrorInit, provided by the RTCErrorInit$Typings extension

getter/setter pair
receivedAlert ↔ num?

Available on RTCErrorInit, provided by the RTCErrorInit$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sctpCauseCode ↔ num?

Available on RTCErrorInit, provided by the RTCErrorInit$Typings extension

getter/setter pair
sdpLineNumber ↔ num?

Available on RTCErrorInit, provided by the RTCErrorInit$Typings extension

getter/setter pair
sentAlert ↔ num?

Available on RTCErrorInit, provided by the RTCErrorInit$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited