ReadableStreamBYOBReader class

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

ReadableStreamBYOBReader(ReadableStream stream)
factory

Properties

cancel ↔ Future<void> Function([dynamic])

Available on ReadableStreamGenericReader, provided by the ReadableStreamGenericReader$Typings extension

getter/setter pair
closed → Future

Available on ReadableStreamGenericReader, provided by the ReadableStreamGenericReader$Typings extension

MDN Reference
no setter
hashCode → int
The hash code for this object.
no setterinherited
read ↔ Future<ReadableStreamReadResult<T>> Function<T extends ArrayBufferView>(T)

Available on ReadableStreamBYOBReader, provided by the ReadableStreamBYOBReader$Typings extension

getter/setter pair
releaseLock ↔ void Function()

Available on ReadableStreamBYOBReader, provided by the ReadableStreamBYOBReader$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited