ReadableStreamGetReaderOptions class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Properties

hashCode → int
The hash code for this object.
no setterinherited
mode ↔ String?

Available on ReadableStreamGetReaderOptions, provided by the ReadableStreamGetReaderOptions$Typings extension

Creates a ReadableStreamBYOBReader and locks the stream to the new reader.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited