ReadonlyMap<K, V> class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

ReadonlyMap({num? size, void forEach(void (dynamic, dynamic, ReadonlyMap), [dynamic])?, dynamic get(dynamic)?, bool has(dynamic)?, IterableIterator<(dynamic, dynamic)> entries()?, IterableIterator keys()?, IterableIterator values()?})
factory

Properties

entries ↔ IterableIterator<(K, V)> Function()

Available on ReadonlyMap<K, V>, provided by the ReadonlyMap$Typings extension

getter/setter pair
forEach ↔ void Function(void (V, K, ReadonlyMap<K, V>), [dynamic])

Available on ReadonlyMap<K, V>, provided by the ReadonlyMap$Typings extension

getter/setter pair
get ↔ V? Function(K)

Available on ReadonlyMap<K, V>, provided by the ReadonlyMap$Typings extension

getter/setter pair
has ↔ bool Function(K)

Available on ReadonlyMap<K, V>, provided by the ReadonlyMap$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keys ↔ IterableIterator<K> Function()

Available on ReadonlyMap<K, V>, provided by the ReadonlyMap$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → num

Available on ReadonlyMap<K, V>, provided by the ReadonlyMap$Typings extension

no setter
values ↔ IterableIterator<V> Function()

Available on ReadonlyMap<K, V>, provided by the ReadonlyMap$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited