ReportingObserverOptions class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

ReportingObserverOptions({bool? buffered, List<String>? types})
factory

Properties

buffered ↔ bool?

Available on ReportingObserverOptions, provided by the ReportingObserverOptions$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
types ↔ List<String>?

Available on ReportingObserverOptions, provided by the ReportingObserverOptions$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited