ResolvedCollatorOptions class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

ResolvedCollatorOptions({String? locale, String? usage, String? sensitivity, bool? ignorePunctuation, String? collation, String? caseFirst, bool? numeric})
factory

Properties

caseFirst ↔ String

Available on ResolvedCollatorOptions, provided by the ResolvedCollatorOptions$Typings extension

getter/setter pair
collation ↔ String

Available on ResolvedCollatorOptions, provided by the ResolvedCollatorOptions$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ignorePunctuation ↔ bool

Available on ResolvedCollatorOptions, provided by the ResolvedCollatorOptions$Typings extension

getter/setter pair
locale ↔ String

Available on ResolvedCollatorOptions, provided by the ResolvedCollatorOptions$Typings extension

getter/setter pair
numeric ↔ bool

Available on ResolvedCollatorOptions, provided by the ResolvedCollatorOptions$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sensitivity ↔ String

Available on ResolvedCollatorOptions, provided by the ResolvedCollatorOptions$Typings extension

getter/setter pair
usage ↔ String

Available on ResolvedCollatorOptions, provided by the ResolvedCollatorOptions$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited