ResolvedDisplayNamesOptions class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

ResolvedDisplayNamesOptions({String? locale, RelativeTimeFormatStyle? style, DisplayNamesType? type, DisplayNamesFallback? fallback, DisplayNamesLanguageDisplay? languageDisplay})
factory

Properties

fallback ↔ DisplayNamesFallback

Available on ResolvedDisplayNamesOptions, provided by the ResolvedDisplayNamesOptions$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
languageDisplay ↔ DisplayNamesLanguageDisplay?

Available on ResolvedDisplayNamesOptions, provided by the ResolvedDisplayNamesOptions$Typings extension

getter/setter pair
locale ↔ String

Available on ResolvedDisplayNamesOptions, provided by the ResolvedDisplayNamesOptions$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style ↔ RelativeTimeFormatStyle

Available on ResolvedDisplayNamesOptions, provided by the ResolvedDisplayNamesOptions$Typings extension

getter/setter pair
type ↔ DisplayNamesType

Available on ResolvedDisplayNamesOptions, provided by the ResolvedDisplayNamesOptions$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited