ResolvedListFormatOptions class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

ResolvedListFormatOptions({String? locale, ListFormatStyle? style, ListFormatType? type})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
locale ↔ String

Available on ResolvedListFormatOptions, provided by the ResolvedListFormatOptions$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style ↔ ListFormatStyle

Available on ResolvedListFormatOptions, provided by the ResolvedListFormatOptions$Typings extension

getter/setter pair
type ↔ ListFormatType

Available on ResolvedListFormatOptions, provided by the ResolvedListFormatOptions$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited