SVGStringList class

The SVGStringList defines a list of DOMString objects.

MDN Reference

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

SVGStringList()
factory

Properties

appendItem ↔ String Function(String data)

Available on SVGStringList, provided by the SVGStringList$Typings extension

getter/setter pair
clear ↔ void Function()

Available on SVGStringList, provided by the SVGStringList$Typings extension

getter/setter pair
getItem ↔ String Function(num)

Available on SVGStringList, provided by the SVGStringList$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
initialize ↔ String Function(String data)

Available on SVGStringList, provided by the SVGStringList$Typings extension

getter/setter pair
insertItemBefore ↔ String Function(String, num)

Available on SVGStringList, provided by the SVGStringList$Typings extension

getter/setter pair
length → num

Available on SVGStringList, provided by the SVGStringList$Typings extension

no setter
numberOfItems → num

Available on SVGStringList, provided by the SVGStringList$Typings extension

no setter
removeItem ↔ String Function(num)

Available on SVGStringList, provided by the SVGStringList$Typings extension

getter/setter pair
replaceItem ↔ String Function(String, num)

Available on SVGStringList, provided by the SVGStringList$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](num index) → String

Available on SVGStringList, provided by the SVGStringList$Typings extension

operator []=(num index, String value) → void

Available on SVGStringList, provided by the SVGStringList$Typings extension