Screen class

A screen, usually the one on which the current window is being rendered, and is obtained using window.screen.

MDN Reference

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

Screen()
factory

Properties

availHeight → num

Available on Screen, provided by the Screen$Typings extension

MDN Reference
no setter
availWidth → num

Available on Screen, provided by the Screen$Typings extension

MDN Reference
no setter
colorDepth → num

Available on Screen, provided by the Screen$Typings extension

MDN Reference
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → num

Available on Screen, provided by the Screen$Typings extension

MDN Reference
no setter
orientation → ScreenOrientation

Available on Screen, provided by the Screen$Typings extension

MDN Reference
no setter
pixelDepth → num

Available on Screen, provided by the Screen$Typings extension

MDN Reference
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → num

Available on Screen, provided by the Screen$Typings extension

MDN Reference
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited