ScrollToOptions class

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

ScrollToOptions({num? left, num? top, ScrollBehavior? behavior})
factory

Properties

behavior ↔ ScrollBehavior?

Available on ScrollOptions, provided by the ScrollOptions$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
left ↔ num?

Available on ScrollToOptions, provided by the ScrollToOptions$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top ↔ num?

Available on ScrollToOptions, provided by the ScrollToOptions$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited