ShadowRootInit class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

ShadowRootInit({bool? delegatesFocus, ShadowRootMode? mode, SlotAssignmentMode? slotAssignment})
factory

Properties

delegatesFocus ↔ bool?

Available on ShadowRootInit, provided by the ShadowRootInit$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mode ↔ ShadowRootMode

Available on ShadowRootInit, provided by the ShadowRootInit$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slotAssignment ↔ SlotAssignmentMode?

Available on ShadowRootInit, provided by the ShadowRootInit$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited