StorageEvent$Typings extension

on

Properties

initStorageEvent ↔ void Function(String, [bool?, bool?, String?, String?, String?, Object?, Storage?])

Available on StorageEvent, provided by the StorageEvent$Typings extension

getter/setter pair
key → String?

Available on StorageEvent, provided by the StorageEvent$Typings extension

Returns the key of the storage item being changed.
no setter
newValue → String?

Available on StorageEvent, provided by the StorageEvent$Typings extension

Returns the new value of the key of the storage item whose value is being changed.
no setter
oldValue → String?

Available on StorageEvent, provided by the StorageEvent$Typings extension

Returns the old value of the key of the storage item whose value is being changed.
no setter
storageArea → Storage?

Available on StorageEvent, provided by the StorageEvent$Typings extension

Returns the Storage object that was affected.
no setter
url → String

Available on StorageEvent, provided by the StorageEvent$Typings extension

Returns the URL of the document whose storage item changed.
no setter