StorageEventInit class

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

StorageEventInit({String? key, String? newValue, String? oldValue, Storage? storageArea, String? url, bool? bubbles, bool? cancelable, bool? composed})
factory

Properties

bubbles ↔ bool?

Available on EventInit, provided by the EventInit$Typings extension

getter/setter pair
cancelable ↔ bool?

Available on EventInit, provided by the EventInit$Typings extension

getter/setter pair
composed ↔ bool?

Available on EventInit, provided by the EventInit$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?

Available on StorageEventInit, provided by the StorageEventInit$Typings extension

getter/setter pair
newValue ↔ String?

Available on StorageEventInit, provided by the StorageEventInit$Typings extension

getter/setter pair
oldValue ↔ String?

Available on StorageEventInit, provided by the StorageEventInit$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageArea ↔ Storage?

Available on StorageEventInit, provided by the StorageEventInit$Typings extension

getter/setter pair
url ↔ String?

Available on StorageEventInit, provided by the StorageEventInit$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited