StringConstructor class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

StringConstructor()

Properties

fromCharCode ↔ String Function([Iterable?])

Available on StringConstructor, provided by the StringConstructor$Typings extension

getter/setter pair
fromCodePoint ↔ String Function([Iterable?])

Available on StringConstructor, provided by the StringConstructor$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
raw ↔ String Function(dynamic, [Iterable?])

Available on StringConstructor, provided by the StringConstructor$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call([dynamic value]) → String

Available on StringConstructor, provided by the StringConstructor$Typings extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited