TextDecoderStream class

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

TextDecoderStream([String? label, TextDecoderOptions? options])
factory

Properties

encoding → String

Available on TextDecoderCommon, provided by the TextDecoderCommon$Typings extension

Returns encoding's name, lowercased.
no setter
fatal → bool

Available on TextDecoderCommon, provided by the TextDecoderCommon$Typings extension

Returns true if error mode is "fatal", otherwise false.
no setter
hashCode → int
The hash code for this object.
no setterinherited
ignoreBOM → bool

Available on TextDecoderCommon, provided by the TextDecoderCommon$Typings extension

Returns the value of ignore BOM.
no setter
readable → ReadableStream

Available on GenericTransformStream, provided by the GenericTransformStream$Typings extension

MDN Reference
no setter
readable → ReadableStream<String>

Available on TextDecoderStream, provided by the TextDecoderStream$Typings extension

MDN Reference
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
writable → WritableStream

Available on GenericTransformStream, provided by the GenericTransformStream$Typings extension

MDN Reference
no setter
writable → WritableStream<Object>

Available on TextDecoderStream, provided by the TextDecoderStream$Typings extension

MDN Reference
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited