TextEncoderStream class

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

TextEncoderStream()
factory

Properties

encoding → String

Available on TextEncoderCommon, provided by the TextEncoderCommon$Typings extension

Returns "utf-8".
no setter
hashCode → int
The hash code for this object.
no setterinherited
readable → ReadableStream

Available on GenericTransformStream, provided by the GenericTransformStream$Typings extension

MDN Reference
no setter
readable → ReadableStream<Uint8List>

Available on TextEncoderStream, provided by the TextEncoderStream$Typings extension

MDN Reference
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
writable → WritableStream

Available on GenericTransformStream, provided by the GenericTransformStream$Typings extension

MDN Reference
no setter
writable → WritableStream<String>

Available on TextEncoderStream, provided by the TextEncoderStream$Typings extension

MDN Reference
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited