TextStreamBase class

Implementers
Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

TextStreamBase({num? column, num? line, void close()?})
factory

Properties

close ↔ void Function()

Available on TextStreamBase, provided by the TextStreamBase$Typings extension

getter/setter pair
column ↔ num

Available on TextStreamBase, provided by the TextStreamBase$Typings extension

The column number of the current character position in an input stream.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
line ↔ num

Available on TextStreamBase, provided by the TextStreamBase$Typings extension

The current line number in an input stream.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited