VBArray<T> class

Enables reading from a COM safe array, which might have an alternate lower bound, or multiple dimensions.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

VBArray(SafeArray<T> safeArray)
factory

Properties

dimensions ↔ num Function()

Available on VBArray<T>, provided by the VBArray$Typings extension

getter/setter pair
getItem ↔ T Function(num, [Iterable?])

Available on VBArray<T>, provided by the VBArray$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lbound ↔ num Function([num?])

Available on VBArray<T>, provided by the VBArray$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toArray ↔ List<T> Function()

Available on VBArray<T>, provided by the VBArray$Typings extension

getter/setter pair
ubound ↔ num Function([num?])

Available on VBArray<T>, provided by the VBArray$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited