VideoConfiguration class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

VideoConfiguration({num? bitrate, ColorGamut? colorGamut, String? contentType, num? framerate, HdrMetadataType? hdrMetadataType, num? height, String? scalabilityMode, TransferFunction? transferFunction, num? width})
factory

Properties

bitrate ↔ num

Available on VideoConfiguration, provided by the VideoConfiguration$Typings extension

getter/setter pair
colorGamut ↔ ColorGamut?

Available on VideoConfiguration, provided by the VideoConfiguration$Typings extension

getter/setter pair
contentType ↔ String

Available on VideoConfiguration, provided by the VideoConfiguration$Typings extension

getter/setter pair
framerate ↔ num

Available on VideoConfiguration, provided by the VideoConfiguration$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hdrMetadataType ↔ HdrMetadataType?

Available on VideoConfiguration, provided by the VideoConfiguration$Typings extension

getter/setter pair
height ↔ num

Available on VideoConfiguration, provided by the VideoConfiguration$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scalabilityMode ↔ String?

Available on VideoConfiguration, provided by the VideoConfiguration$Typings extension

getter/setter pair
transferFunction ↔ TransferFunction?

Available on VideoConfiguration, provided by the VideoConfiguration$Typings extension

getter/setter pair
width ↔ num

Available on VideoConfiguration, provided by the VideoConfiguration$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited