VideoDecoderSupport class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

VideoDecoderSupport({VideoDecoderConfig? config, bool? supported})
factory

Properties

config ↔ VideoDecoderConfig?

Available on VideoDecoderSupport, provided by the VideoDecoderSupport$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supported ↔ bool?

Available on VideoDecoderSupport, provided by the VideoDecoderSupport$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited