VideoEncoderSupport class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

VideoEncoderSupport({VideoEncoderConfig? config, bool? supported})
factory

Properties

config ↔ VideoEncoderConfig?

Available on VideoEncoderSupport, provided by the VideoEncoderSupport$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supported ↔ bool?

Available on VideoEncoderSupport, provided by the VideoEncoderSupport$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited