WritableStream<W> class

This Streams API interface provides a standard abstraction for writing streaming data to a destination, known as a sink. This object comes with built-in backpressure and queuing.

MDN Reference

Implementers
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

WritableStream([UnderlyingSink<W>? underlyingSink, QueuingStrategy<W>? strategy])
factory

Properties

abort ↔ Future<void> Function([dynamic])

Available on WritableStream<W>, provided by the WritableStream$Typings extension

getter/setter pair
close ↔ Future<void> Function()

Available on WritableStream<W>, provided by the WritableStream$Typings extension

getter/setter pair
getWriter ↔ WritableStreamDefaultWriter<W> Function()

Available on WritableStream<W>, provided by the WritableStream$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
locked → bool

Available on WritableStream<W>, provided by the WritableStream$Typings extension

MDN Reference
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited