XPathEvaluatorBase class

Implementers
Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

XPathEvaluatorBase({XPathExpression createExpression(String, [Object?])?, Node createNSResolver(Node)?, XPathResult evaluate(String, Node, [Object?, num?, XPathResult?])?})
factory

Properties

createExpression ↔ XPathExpression Function(String, [Object?])

Available on XPathEvaluatorBase, provided by the XPathEvaluatorBase$Typings extension

getter/setter pair
createNSResolver ↔ Node Function(Node)

Available on XPathEvaluatorBase, provided by the XPathEvaluatorBase$Typings extension

getter/setter pair
evaluate ↔ XPathResult Function(String, Node, [Object?, num?, XPathResult?])

Available on XPathEvaluatorBase, provided by the XPathEvaluatorBase$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited