XPathResult class

The results generated by evaluating an XPath expression within the context of a given node.

MDN Reference

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

XPathResult()
factory

Properties

anyType → num

Available on XPathResult, provided by the XPathResult$Typings extension

no setter
anyUnorderedNodeType → num

Available on XPathResult, provided by the XPathResult$Typings extension

no setter
booleanType → num

Available on XPathResult, provided by the XPathResult$Typings extension

no setter
booleanValue → bool

Available on XPathResult, provided by the XPathResult$Typings extension

MDN Reference
no setter
firstOrderedNodeType → num

Available on XPathResult, provided by the XPathResult$Typings extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
invalidIteratorState → bool

Available on XPathResult, provided by the XPathResult$Typings extension

MDN Reference
no setter
iterateNext ↔ Node? Function()

Available on XPathResult, provided by the XPathResult$Typings extension

getter/setter pair
numberType → num

Available on XPathResult, provided by the XPathResult$Typings extension

no setter
numberValue → num

Available on XPathResult, provided by the XPathResult$Typings extension

MDN Reference
no setter
orderedNodeIteratorType → num

Available on XPathResult, provided by the XPathResult$Typings extension

no setter
orderedNodeSnapshotType → num

Available on XPathResult, provided by the XPathResult$Typings extension

no setter
resultType → num

Available on XPathResult, provided by the XPathResult$Typings extension

MDN Reference
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
singleNodeValue → Node?

Available on XPathResult, provided by the XPathResult$Typings extension

MDN Reference
no setter
snapshotItem ↔ Node? Function(num)

Available on XPathResult, provided by the XPathResult$Typings extension

getter/setter pair
snapshotLength → num

Available on XPathResult, provided by the XPathResult$Typings extension

MDN Reference
no setter
stringType → num

Available on XPathResult, provided by the XPathResult$Typings extension

no setter
stringValue → String

Available on XPathResult, provided by the XPathResult$Typings extension

MDN Reference
no setter
unorderedNodeIteratorType → num

Available on XPathResult, provided by the XPathResult$Typings extension

no setter
unorderedNodeSnapshotType → num

Available on XPathResult, provided by the XPathResult$Typings extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

anyType → num
no setter
anyUnorderedNodeType → num
no setter
booleanType → num
no setter
firstOrderedNodeType → num
no setter
numberType → num
no setter
orderedNodeIteratorType → num
no setter
orderedNodeSnapshotType → num
no setter
stringType → num
no setter
unorderedNodeIteratorType → num
no setter
unorderedNodeSnapshotType → num
no setter