CommandObject class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

CommandObject({num? pos, String? c, num? caret, dynamic remove, dynamic insert, dynamic refreshFromBuffer, num? rewritePosition})
factory

Properties

c ↔ String?

Available on CommandObject, provided by the CommandObject$Typings extension

Character to insert.
getter/setter pair
caret ↔ num?

Available on CommandObject, provided by the CommandObject$Typings extension

Position of the caret.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
insert ↔ dynamic

Available on CommandObject, provided by the CommandObject$Typings extension

Position(s) to add.
getter/setter pair
pos ↔ num?

Available on CommandObject, provided by the CommandObject$Typings extension

Position to insert.
getter/setter pair
refreshFromBuffer ↔ dynamic

Available on CommandObject, provided by the CommandObject$Typings extension

  • true => refresh validPositions from the complete buffer .
  • { start: , end: } => refresh from start to end.
  • getter/setter pair
    remove ↔ dynamic

    Available on CommandObject, provided by the CommandObject$Typings extension

    Position(s) to remove.
    getter/setter pair
    rewritePosition ↔ num?

    Available on CommandObject, provided by the CommandObject$Typings extension

    Rewrite the maskPos within the isvalid function.
    getter/setter pair
    runtimeType → Type
    A representation of the runtime type of the object.
    no setterinherited

    Methods

    noSuchMethod(Invocation invocation) → dynamic
    Invoked when a nonexistent method or property is accessed.
    inherited
    toString() → String
    A string representation of this object.
    inherited

    Operators

    operator ==(Object other) → bool
    The equality operator.
    inherited