Definition class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

Definition({Object? validator, Casing? casing, num? cardinality, String? placeholder, String? definitionSymbol})
factory

Properties

cardinality ↔ num?

Available on Definition, provided by the Definition$Typings extension

getter/setter pair
casing ↔ Casing?

Available on Definition, provided by the Definition$Typings extension

getter/setter pair
definitionSymbol ↔ String?

Available on Definition, provided by the Definition$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
placeholder ↔ String?

Available on Definition, provided by the Definition$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validator ↔ Object

Available on Definition, provided by the Definition$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited