InsertPosition class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

InsertPosition({num? pos, String? c, bool? fromIsValid, bool? strict})
factory

Properties

c ↔ String

Available on InsertPosition, provided by the InsertPosition$Typings extension

Character to insert.
getter/setter pair
fromIsValid ↔ bool?

Available on InsertPosition, provided by the InsertPosition$Typings extension

@default true
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pos ↔ num

Available on InsertPosition, provided by the InsertPosition$Typings extension

Position to insert.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strict ↔ bool?

Available on InsertPosition, provided by the InsertPosition$Typings extension

@default true
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited