$ModuleNotebooks class

Available extensions
Annotations
  • @JS.new('vscode.notebooks')
  • @staticInterop

Constructors

$ModuleNotebooks()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createNotebookController(String id, String notebookType, String label, [FutureOr<void> handler(List<NotebookCell>, NotebookDocument, NotebookController)?]) → NotebookController

Available on $ModuleNotebooks, provided by the $ModuleNotebooks$Typings extension

Creates a new notebook controller.
createRendererMessaging(String rendererId) → NotebookRendererMessaging

Available on $ModuleNotebooks, provided by the $ModuleNotebooks$Typings extension

Creates a new messaging instance used to communicate with a specific renderer.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerNotebookCellStatusBarItemProvider(String notebookType, NotebookCellStatusBarItemProvider provider) → Disposable

Available on $ModuleNotebooks, provided by the $ModuleNotebooks$Typings extension

Register a {@link NotebookCellStatusBarItemProvidercell statusbar item provider} for the given notebook type.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited