$ModuleScm class

Available extensions
Annotations
  • @JS.new('vscode.scm')
  • @staticInterop

Constructors

$ModuleScm()

Properties

hashCode → int
The hash code for this object.
no setterinherited
inputBox → SourceControlInputBox

Available on $ModuleScm, provided by the $ModuleScm$Typings extension

The {@link SourceControlInputBoxinput box} for the last source control created by the extension.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createSourceControl(String id, String label, [Uri? rootUri]) → SourceControl

Available on $ModuleScm, provided by the $ModuleScm$Typings extension

Creates a new {@link SourceControlsource control} instance.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited