$ModuleTasks class

Available extensions
Annotations
  • @JS.new('vscode.tasks')
  • @staticInterop

Constructors

$ModuleTasks()

Properties

hashCode → int
The hash code for this object.
no setterinherited
onDidEndTask → Event<TaskEndEvent>

Available on $ModuleTasks, provided by the $ModuleTasks$Typings extension

Fires when a task ends.
no setter
onDidEndTaskProcess → Event<TaskProcessEndEvent>

Available on $ModuleTasks, provided by the $ModuleTasks$Typings extension

Fires when the underlying process has ended. This event will not fire for tasks that don't execute an underlying process.
no setter
onDidStartTask → Event<TaskStartEvent>

Available on $ModuleTasks, provided by the $ModuleTasks$Typings extension

Fires when a task starts.
no setter
onDidStartTaskProcess → Event<TaskProcessStartEvent>

Available on $ModuleTasks, provided by the $ModuleTasks$Typings extension

Fires when the underlying process has been started. This event will not fire for tasks that don't execute an underlying process.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskExecutions → List<TaskExecution>

Available on $ModuleTasks, provided by the $ModuleTasks$Typings extension

The currently active task executions or an empty array.
no setter

Methods

executeTask(Task task) → Future

Available on $ModuleTasks, provided by the $ModuleTasks$Typings extension

Executes a task that is managed by the editor. The returned task execution can be used to terminate the task.
fetchTasks([TaskFilter? filter]) → Future

Available on $ModuleTasks, provided by the $ModuleTasks$Typings extension

Fetches all tasks available in the systems. This includes tasks from tasks.json files as well as tasks from task providers contributed through extensions.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited