AuthenticationProviderAuthenticationSessionsChangeEvent$Typings extension

on

Properties

added → List<AuthenticationSession>?

Available on AuthenticationProviderAuthenticationSessionsChangeEvent, provided by the AuthenticationProviderAuthenticationSessionsChangeEvent$Typings extension

The {@link AuthenticationSessionAuthenticationSessions} of the {@link AuthenticationProvider} that have been added.
no setter
changed → List<AuthenticationSession>?

Available on AuthenticationProviderAuthenticationSessionsChangeEvent, provided by the AuthenticationProviderAuthenticationSessionsChangeEvent$Typings extension

The {@link AuthenticationSessionAuthenticationSessions} of the {@link AuthenticationProvider} that have been changed. A session changes when its data excluding the id are updated. An example of this is a session refresh that results in a new access token being set for the session.
no setter
removed → List<AuthenticationSession>?

Available on AuthenticationProviderAuthenticationSessionsChangeEvent, provided by the AuthenticationProviderAuthenticationSessionsChangeEvent$Typings extension

The {@link AuthenticationSessionAuthenticationSessions} of the {@link AuthenticationProvider} that have been removed.
no setter