green property
num
get
green
The green component of this color in the range 0-1.
Implementation
_i2.num get green => _i5.getProperty(
this,
'green',
);
The green component of this color in the range 0-1.
_i2.num get green => _i5.getProperty(
this,
'green',
);