ColorInformation class

Represents a color range from a document.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

ColorInformation(Range range, Color color)
factory

Properties

color ↔ Color

Available on ColorInformation, provided by the ColorInformation$Typings extension

The actual color value for this color range.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
range ↔ Range

Available on ColorInformation, provided by the ColorInformation$Typings extension

The range in the document where this color appears.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited