CommentController class

A comment controller is able to provide {@link CommentThreadcomments} support to the editor and provide users various ways to interact with comments.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

CommentController({String? id, String? label, CommentOptions? options, CommentingRangeProvider? commentingRangeProvider, Future reactionHandler(Comment, CommentReaction)?, CommentThread createCommentThread(Uri, Range, List<Comment>)?, void dispose()?})
factory

Properties

commentingRangeProvider ↔ CommentingRangeProvider?

Available on CommentController, provided by the CommentController$Typings extension

Optional commenting range provider. Provide a list {@link Range ranges} which support commenting to any given resource uri.
getter/setter pair
createCommentThread ↔ CommentThread Function(Uri, Range, List<Comment>)

Available on CommentController, provided by the CommentController$Typings extension

getter/setter pair
dispose ↔ void Function()

Available on CommentController, provided by the CommentController$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id → String

Available on CommentController, provided by the CommentController$Typings extension

The id of this comment controller.
no setter
label → String

Available on CommentController, provided by the CommentController$Typings extension

The human-readable label of this comment controller.
no setter
options ↔ CommentOptions?

Available on CommentController, provided by the CommentController$Typings extension

Comment controller options
getter/setter pair
reactionHandler ↔ Future Function(Comment, CommentReaction)?

Available on CommentController, provided by the CommentController$Typings extension

Optional reaction handler for creating and deleting reactions on a {@link Comment}.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited