CommentOptions class

Represents a {@link CommentControllercomment controller}'s {@link CommentController.optionsoptions}.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

CommentOptions({String? prompt, String? placeHolder})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
placeHolder ↔ String?

Available on CommentOptions, provided by the CommentOptions$Typings extension

An optional string to show as placeholder in the comment input box when it's focused.
getter/setter pair
prompt ↔ String?

Available on CommentOptions, provided by the CommentOptions$Typings extension

An optional string to show on the comment input box when it's collapsed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited