CommentReaction class

Reactions of a {@link Comment}

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

CommentReaction({String? label, Object? iconPath, num? count, bool? authorHasReacted})
factory

Properties

authorHasReacted → bool

Available on CommentReaction, provided by the CommentReaction$Typings extension

Whether the {@link CommentAuthorInformationauthor} of the comment has reacted to this reaction
no setter
count → num

Available on CommentReaction, provided by the CommentReaction$Typings extension

The number of users who have reacted to this reaction
no setter
hashCode → int
The hash code for this object.
no setterinherited
iconPath → Object

Available on CommentReaction, provided by the CommentReaction$Typings extension

Icon for the reaction shown in UI.
no setter
label → String

Available on CommentReaction, provided by the CommentReaction$Typings extension

The human-readable label for the reaction
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited