CommentReply class

Command argument for actions registered in comments/commentThread/context.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

CommentReply({CommentThread? thread, String? text})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String

Available on CommentReply, provided by the CommentReply$Typings extension

The value in the comment editor
getter/setter pair
thread ↔ CommentThread

Available on CommentReply, provided by the CommentReply$Typings extension

The active {@link CommentThread comment thread}
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited