CommentThread class

A collection of {@link Commentcomments} representing a conversation at a particular range in a document.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

CommentThread({Uri? uri, Range? range, List<Comment>? comments, CommentThreadCollapsibleState? collapsibleState, bool? canReply, String? contextValue, String? label, CommentThreadState? state, void dispose()?})
factory

Properties

canReply ↔ bool

Available on CommentThread, provided by the CommentThread$Typings extension

Whether the thread supports reply. Defaults to true.
getter/setter pair
collapsibleState ↔ CommentThreadCollapsibleState

Available on CommentThread, provided by the CommentThread$Typings extension

Whether the thread should be collapsed or expanded when opening the document. Defaults to Collapsed.
getter/setter pair
comments ↔ List<Comment>

Available on CommentThread, provided by the CommentThread$Typings extension

The ordered comments of the thread.
getter/setter pair
contextValue ↔ String?

Available on CommentThread, provided by the CommentThread$Typings extension

Context value of the comment thread. This can be used to contribute thread specific actions. For example, a comment thread is given a context value as editable. When contributing actions to comments/commentThread/title using menus extension point, you can specify context value for key commentThread in when expression like commentThread == editable.
getter/setter pair
dispose ↔ void Function()

Available on CommentThread, provided by the CommentThread$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
label ↔ String?

Available on CommentThread, provided by the CommentThread$Typings extension

The optional human-readable label describing the {@link CommentThread Comment Thread}
getter/setter pair
range ↔ Range

Available on CommentThread, provided by the CommentThread$Typings extension

The range the comment thread is located within the document. The thread icon will be shown at the last line of the range.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ CommentThreadState?

Available on CommentThread, provided by the CommentThread$Typings extension

The optional state of a comment thread, which may affect how the comment is displayed.
getter/setter pair
uri → Uri

Available on CommentThread, provided by the CommentThread$Typings extension

The uri of the document the thread has been created on.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited