CustomDocumentOpenContext$Typings extension

on

Properties

backupId → String?

Available on CustomDocumentOpenContext, provided by the CustomDocumentOpenContext$Typings extension

The id of the backup to restore the document from or undefined if there is no backup.
no setter
untitledDocumentData → Uint8List?

Available on CustomDocumentOpenContext, provided by the CustomDocumentOpenContext$Typings extension

If the URI is an untitled file, this will be populated with the byte data of that file
no setter