CustomDocumentOpenContext class

Additional information about the opening custom document.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

CustomDocumentOpenContext({String? backupId, Uint8List? untitledDocumentData})
factory

Properties

backupId → String?

Available on CustomDocumentOpenContext, provided by the CustomDocumentOpenContext$Typings extension

The id of the backup to restore the document from or undefined if there is no backup.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
untitledDocumentData → Uint8List?

Available on CustomDocumentOpenContext, provided by the CustomDocumentOpenContext$Typings extension

If the URI is an untitled file, this will be populated with the byte data of that file
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited