DebugAdapterDescriptorFactory class

A debug adaper factory that creates {@link DebugAdapterDescriptordebug adapter descriptors}.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

DebugAdapterDescriptorFactory({FutureOr<Object> createDebugAdapterDescriptor(DebugSession, [DebugAdapterExecutable?])?})
factory

Properties

createDebugAdapterDescriptor ↔ FutureOr<Object> Function(DebugSession, [DebugAdapterExecutable?])

Available on DebugAdapterDescriptorFactory, provided by the DebugAdapterDescriptorFactory$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited