DebugAdapterExecutableOptions class

Options for a debug adapter executable.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

DebugAdapterExecutableOptions({Object? env, String? cwd})
factory

Properties

cwd ↔ String?

Available on DebugAdapterExecutableOptions, provided by the DebugAdapterExecutableOptions$Typings extension

The current working directory for the executed debug adapter.
getter/setter pair
env ↔ Object?

Available on DebugAdapterExecutableOptions, provided by the DebugAdapterExecutableOptions$Typings extension

The additional environment of the executed program or shell. If omitted the parent process' environment is used. If provided it is merged with the parent process' environment.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited