DebugConfiguration class

Configuration for a debug session.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

DebugConfiguration({String? type, String? name, String? request})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String

Available on DebugConfiguration, provided by the DebugConfiguration$Typings extension

The name of the debug session.
getter/setter pair
request ↔ String

Available on DebugConfiguration, provided by the DebugConfiguration$Typings extension

The request type of the debug session.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String

Available on DebugConfiguration, provided by the DebugConfiguration$Typings extension

The type of the debug session.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](String index) → dynamic

Available on DebugConfiguration, provided by the DebugConfiguration$Typings extension

operator []=(String index, dynamic value) → void

Available on DebugConfiguration, provided by the DebugConfiguration$Typings extension