DebugSession class

A debug session.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

DebugSession({String? id, String? type, DebugSession? parentSession, String? name, WorkspaceFolder? workspaceFolder, DebugConfiguration? configuration, Future customRequest(String, [dynamic])?, Future getDebugProtocolBreakpoint(Breakpoint)?})
factory

Properties

configuration → DebugConfiguration

Available on DebugSession, provided by the DebugSession$Typings extension

The "resolved" {@link DebugConfigurationdebug configuration} of this session. "Resolved" means that
no setter
customRequest ↔ Future Function(String, [dynamic])

Available on DebugSession, provided by the DebugSession$Typings extension

getter/setter pair
getDebugProtocolBreakpoint ↔ Future Function(Breakpoint)

Available on DebugSession, provided by the DebugSession$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id → String

Available on DebugSession, provided by the DebugSession$Typings extension

The unique ID of this debug session.
no setter
name ↔ String

Available on DebugSession, provided by the DebugSession$Typings extension

The debug session's name is initially taken from the {@link DebugConfiguration debug configuration}. Any changes will be properly reflected in the UI.
getter/setter pair
parentSession → DebugSession?

Available on DebugSession, provided by the DebugSession$Typings extension

The parent session of this debug session, if it was created as a child.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String

Available on DebugSession, provided by the DebugSession$Typings extension

The debug session's type from the {@link DebugConfigurationdebug configuration}.
no setter
workspaceFolder → WorkspaceFolder?

Available on DebugSession, provided by the DebugSession$Typings extension

The workspace folder of this session or undefined for a folderless setup.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited