FileDecoration class

A file decoration represents metadata that can be rendered with a file.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

FileDecoration([String? badge, String? tooltip, ThemeColor? color])
factory

Properties

badge ↔ String

Available on FileDecoration, provided by the FileDecoration$Typings extension

A very short string that represents this decoration.
getter/setter pair
color ↔ ThemeColor

Available on FileDecoration, provided by the FileDecoration$Typings extension

The color of this decoration.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
propagate ↔ bool

Available on FileDecoration, provided by the FileDecoration$Typings extension

A flag expressing that this decoration should be propagated to its parents.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tooltip ↔ String

Available on FileDecoration, provided by the FileDecoration$Typings extension

A human-readable tooltip for this decoration.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited