FileSystem class

The file system interface exposes the editor's built-in and contributed {@link FileSystemProviderfile system providers}. It allows extensions to work with files from the local disk as well as files from remote places, like the remote extension host or ftp-servers.

Note that an instance of this interface is available as {@linkcode workspace.fs}.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

FileSystem({Future stat(Uri)?, Future readDirectory(Uri)?, Future createDirectory(Uri)?, Future readFile(Uri)?, Future writeFile(Uri, Uint8List)?, Future delete(Uri, [dynamic])?, Future rename(Uri, Uri, [dynamic])?, Future copy(Uri, Uri, [dynamic])?, bool? isWritableFileSystem(String)?})
factory

Properties

copy ↔ Future Function(Uri, Uri, [dynamic])

Available on FileSystem, provided by the FileSystem$Typings extension

getter/setter pair
createDirectory ↔ Future Function(Uri)

Available on FileSystem, provided by the FileSystem$Typings extension

getter/setter pair
delete ↔ Future Function(Uri, [dynamic])

Available on FileSystem, provided by the FileSystem$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isWritableFileSystem ↔ bool? Function(String)

Available on FileSystem, provided by the FileSystem$Typings extension

getter/setter pair
readDirectory ↔ Future Function(Uri)

Available on FileSystem, provided by the FileSystem$Typings extension

getter/setter pair
readFile ↔ Future Function(Uri)

Available on FileSystem, provided by the FileSystem$Typings extension

getter/setter pair
rename ↔ Future Function(Uri, Uri, [dynamic])

Available on FileSystem, provided by the FileSystem$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stat ↔ Future Function(Uri)

Available on FileSystem, provided by the FileSystem$Typings extension

getter/setter pair
writeFile ↔ Future Function(Uri, Uint8List)

Available on FileSystem, provided by the FileSystem$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited