FileSystemWatcher$Typings extension

on

Properties

ignoreChangeEvents → bool

Available on FileSystemWatcher, provided by the FileSystemWatcher$Typings extension

true if this file system watcher has been created such that it ignores change file system events.
no setter
ignoreCreateEvents → bool

Available on FileSystemWatcher, provided by the FileSystemWatcher$Typings extension

true if this file system watcher has been created such that it ignores creation file system events.
no setter
ignoreDeleteEvents → bool

Available on FileSystemWatcher, provided by the FileSystemWatcher$Typings extension

true if this file system watcher has been created such that it ignores delete file system events.
no setter
onDidChange → Event<Uri>

Available on FileSystemWatcher, provided by the FileSystemWatcher$Typings extension

An event which fires on file/folder change.
no setter
onDidCreate → Event<Uri>

Available on FileSystemWatcher, provided by the FileSystemWatcher$Typings extension

An event which fires on file/folder creation.
no setter
onDidDelete → Event<Uri>

Available on FileSystemWatcher, provided by the FileSystemWatcher$Typings extension

An event which fires on file/folder deletion.
no setter