FileSystemWatcher class

A file system watcher notifies about changes to files and folders on disk or from other {@link FileSystemProviderFileSystemProviders}.

To get an instance of a FileSystemWatcher use {@link workspace.createFileSystemWatchercreateFileSystemWatcher}.

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

FileSystemWatcher({bool? ignoreCreateEvents, bool? ignoreChangeEvents, bool? ignoreDeleteEvents, Event<Uri>? onDidCreate, Event<Uri>? onDidChange, Event<Uri>? onDidDelete})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
ignoreChangeEvents → bool

Available on FileSystemWatcher, provided by the FileSystemWatcher$Typings extension

true if this file system watcher has been created such that it ignores change file system events.
no setter
ignoreCreateEvents → bool

Available on FileSystemWatcher, provided by the FileSystemWatcher$Typings extension

true if this file system watcher has been created such that it ignores creation file system events.
no setter
ignoreDeleteEvents → bool

Available on FileSystemWatcher, provided by the FileSystemWatcher$Typings extension

true if this file system watcher has been created such that it ignores delete file system events.
no setter
onDidChange → Event<Uri>

Available on FileSystemWatcher, provided by the FileSystemWatcher$Typings extension

An event which fires on file/folder change.
no setter
onDidCreate → Event<Uri>

Available on FileSystemWatcher, provided by the FileSystemWatcher$Typings extension

An event which fires on file/folder creation.
no setter
onDidDelete → Event<Uri>

Available on FileSystemWatcher, provided by the FileSystemWatcher$Typings extension

An event which fires on file/folder deletion.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → dynamic

Available on Disposable, provided by the Disposable$Typings extension

Dispose this object.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited