FileWillRenameEvent class

An event that is fired when files are going to be renamed.

To make modifications to the workspace before the files are renamed, call the {@link FileWillCreateEvent.waitUntilwaitUntil}-function with a thenable that resolves to a {@link WorkspaceEditworkspace edit}.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

FileWillRenameEvent({CancellationToken? token, ReadonlyArray<IInline62>? files})
factory

Properties

files → ReadonlyArray

Available on FileWillRenameEvent, provided by the FileWillRenameEvent$Typings extension

The files that are going to be renamed.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → CancellationToken

Available on FileWillRenameEvent, provided by the FileWillRenameEvent$Typings extension

A cancellation token.
no setter
waitUntil → ({void Function(Future thenable) $1, void Function(Future thenable) $2})

Available on FileWillRenameEvent, provided by the FileWillRenameEvent$Typings extension

Overload accessor: $1, $2
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited