FormattingOptions class

Value-object describing what options formatting should use.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

FormattingOptions({num? tabSize, bool? insertSpaces})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
insertSpaces ↔ bool

Available on FormattingOptions, provided by the FormattingOptions$Typings extension

Prefer spaces over tabs.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tabSize ↔ num

Available on FormattingOptions, provided by the FormattingOptions$Typings extension

Size of a tab in spaces.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](String index) → Object

Available on FormattingOptions, provided by the FormattingOptions$Typings extension

operator []=(String index, Object value) → void

Available on FormattingOptions, provided by the FormattingOptions$Typings extension