InlineCompletionItem$Typings extension

on

Properties

command ↔ Command

Available on InlineCompletionItem, provided by the InlineCompletionItem$Typings extension

An optional {@link Command} that is executed after inserting this completion.
getter/setter pair
filterText ↔ String

Available on InlineCompletionItem, provided by the InlineCompletionItem$Typings extension

A text that is used to decide if this inline completion should be shown. When falsy the {@link InlineCompletionItem.insertText} is used.
getter/setter pair
insertText ↔ Object

Available on InlineCompletionItem, provided by the InlineCompletionItem$Typings extension

The text to replace the range with. Must be set. Is used both for the preview and the accept operation.
getter/setter pair
range ↔ Range

Available on InlineCompletionItem, provided by the InlineCompletionItem$Typings extension

The range to replace. Must begin and end on the same line.
getter/setter pair