NotebookCellExecution$Typings extension

on

Properties

appendOutput ↔ Future Function(Object, [NotebookCell?])

Available on NotebookCellExecution, provided by the NotebookCellExecution$Typings extension

getter/setter pair
appendOutputItems ↔ Future Function(Object, NotebookCellOutput)

Available on NotebookCellExecution, provided by the NotebookCellExecution$Typings extension

getter/setter pair
cell → NotebookCell

Available on NotebookCellExecution, provided by the NotebookCellExecution$Typings extension

The {@link NotebookCellcell} for which this execution has been created.
no setter
clearOutput ↔ Future Function([NotebookCell?])

Available on NotebookCellExecution, provided by the NotebookCellExecution$Typings extension

getter/setter pair
end ↔ void Function([bool?, num?])

Available on NotebookCellExecution, provided by the NotebookCellExecution$Typings extension

getter/setter pair
executionOrder ↔ num?

Available on NotebookCellExecution, provided by the NotebookCellExecution$Typings extension

Set and unset the order of this cell execution.
getter/setter pair
replaceOutput ↔ Future Function(Object, [NotebookCell?])

Available on NotebookCellExecution, provided by the NotebookCellExecution$Typings extension

getter/setter pair
replaceOutputItems ↔ Future Function(Object, NotebookCellOutput)

Available on NotebookCellExecution, provided by the NotebookCellExecution$Typings extension

getter/setter pair
start ↔ void Function([num?])

Available on NotebookCellExecution, provided by the NotebookCellExecution$Typings extension

getter/setter pair
token → CancellationToken

Available on NotebookCellExecution, provided by the NotebookCellExecution$Typings extension

A cancellation token which will be triggered when the cell execution is canceled from the UI.
no setter