NotebookDocument class

Represents a notebook which itself is a sequence of {@link NotebookCellcode or markup cells}. Notebook documents are created from {@link NotebookDatanotebook data}.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

NotebookDocument({Uri? uri, String? notebookType, num? version, bool? isDirty, bool? isUntitled, bool? isClosed, Object? metadata, num? cellCount, NotebookCell cellAt(num)?, List<NotebookCell> getCells([NotebookRange?])?, Future save()?})
factory

Properties

cellAt ↔ NotebookCell Function(num)

Available on NotebookDocument, provided by the NotebookDocument$Typings extension

getter/setter pair
cellCount → num

Available on NotebookDocument, provided by the NotebookDocument$Typings extension

The number of cells in the notebook.
no setter
getCells ↔ List<NotebookCell> Function([NotebookRange?])

Available on NotebookDocument, provided by the NotebookDocument$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isClosed → bool

Available on NotebookDocument, provided by the NotebookDocument$Typings extension

true if the notebook has been closed. A closed notebook isn't synchronized anymore and won't be re-used when the same resource is opened again.
no setter
isDirty → bool

Available on NotebookDocument, provided by the NotebookDocument$Typings extension

true if there are unpersisted changes.
no setter
isUntitled → bool

Available on NotebookDocument, provided by the NotebookDocument$Typings extension

Is this notebook representing an untitled file which has not been saved yet.
no setter
metadata → Object

Available on NotebookDocument, provided by the NotebookDocument$Typings extension

Arbitrary metadata for this notebook. Can be anything but must be JSON-stringifyable.
no setter
notebookType → String

Available on NotebookDocument, provided by the NotebookDocument$Typings extension

The type of notebook.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
save ↔ Future Function()

Available on NotebookDocument, provided by the NotebookDocument$Typings extension

getter/setter pair
uri → Uri

Available on NotebookDocument, provided by the NotebookDocument$Typings extension

The associated uri for this notebook.
no setter
version → num

Available on NotebookDocument, provided by the NotebookDocument$Typings extension

The version number of this notebook (it will strictly increase after each change, including undo/redo).
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited