NotebookDocumentCellChange class

Describes a change to a notebook cell.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

NotebookDocumentCellChange({NotebookCell? cell, TextDocument? document, Object? metadata, List<NotebookCellOutput>? outputs, NotebookCellExecutionSummary? executionSummary})
factory

Properties

cell → NotebookCell

Available on NotebookDocumentCellChange, provided by the NotebookDocumentCellChange$Typings extension

The affected cell.
no setter
document → TextDocument?

Available on NotebookDocumentCellChange, provided by the NotebookDocumentCellChange$Typings extension

The document of the cell or undefined when it did not change.
no setter
executionSummary → NotebookCellExecutionSummary?

Available on NotebookDocumentCellChange, provided by the NotebookDocumentCellChange$Typings extension

The new execution summary of the cell or undefined when it did not change.
no setter
hashCode → int
The hash code for this object.
no setterinherited
metadata → Object?

Available on NotebookDocumentCellChange, provided by the NotebookDocumentCellChange$Typings extension

The new metadata of the cell or undefined when it did not change.
no setter
outputs → List<NotebookCellOutput>?

Available on NotebookDocumentCellChange, provided by the NotebookDocumentCellChange$Typings extension

The new outputs of the cell or undefined when they did not change.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited