NotebookDocumentContentChange class

Describes a structural change to a notebook document, e.g newly added and removed cells.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

NotebookDocumentContentChange({NotebookRange? range, List<NotebookCell>? addedCells, List<NotebookCell>? removedCells})
factory

Properties

addedCells → List<NotebookCell>

Available on NotebookDocumentContentChange, provided by the NotebookDocumentContentChange$Typings extension

Cells that have been added to the document.
no setter
hashCode → int
The hash code for this object.
no setterinherited
range → NotebookRange

Available on NotebookDocumentContentChange, provided by the NotebookDocumentContentChange$Typings extension

The range at which cells have been either added or removed.
no setter
removedCells → List<NotebookCell>

Available on NotebookDocumentContentChange, provided by the NotebookDocumentContentChange$Typings extension

Cells that have been removed from the document.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited