SourceControlInputBox class

Represents the input box in the Source Control viewlet.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

SourceControlInputBox({String? value, String? placeholder, bool? enabled, bool? visible})
factory

Properties

enabled ↔ bool

Available on SourceControlInputBox, provided by the SourceControlInputBox$Typings extension

Controls whether the input box is enabled (default is true).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
placeholder ↔ String

Available on SourceControlInputBox, provided by the SourceControlInputBox$Typings extension

A string to show as placeholder in the input box to guide the user.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String

Available on SourceControlInputBox, provided by the SourceControlInputBox$Typings extension

Setter and getter for the contents of the input box.
getter/setter pair
visible ↔ bool

Available on SourceControlInputBox, provided by the SourceControlInputBox$Typings extension

Controls whether the input box is visible (default is true).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited