Tab class

Represents a tab within a {@link TabGroupgroup of tabs}. Tabs are merely the graphical representation within the editor area. A backing editor is not a guarantee.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

Tab({String? label, TabGroup? group, Object? input, bool? isActive, bool? isDirty, bool? isPinned, bool? isPreview})
factory

Properties

group → TabGroup

Available on Tab, provided by the Tab$Typings extension

The group which the tab belongs to.
no setter
hashCode → int
The hash code for this object.
no setterinherited
input → Object

Available on Tab, provided by the Tab$Typings extension

Defines the structure of the tab i.e. text, notebook, custom, etc. Resource and other useful properties are defined on the tab kind.
no setter
isActive → bool

Available on Tab, provided by the Tab$Typings extension

Whether or not the tab is currently active. This is dictated by being the selected tab in the group.
no setter
isDirty → bool

Available on Tab, provided by the Tab$Typings extension

Whether or not the dirty indicator is present on the tab.
no setter
isPinned → bool

Available on Tab, provided by the Tab$Typings extension

Whether or not the tab is pinned (pin icon is present).
no setter
isPreview → bool

Available on Tab, provided by the Tab$Typings extension

Whether or not the tab is in preview mode.
no setter
label → String

Available on Tab, provided by the Tab$Typings extension

The text displayed on the tab.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited