TabInputCustom class

The tab represents a custom editor.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

TabInputCustom(Uri uri, String viewType)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → Uri

Available on TabInputCustom, provided by the TabInputCustom$Typings extension

The uri that the tab is representing.
no setter
viewType → String

Available on TabInputCustom, provided by the TabInputCustom$Typings extension

The type of custom editor.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited