Task$Typings extension

on

Properties

definition ↔ TaskDefinition

Available on Task, provided by the Task$Typings extension

The task's definition.
getter/setter pair
detail ↔ String

Available on Task, provided by the Task$Typings extension

A human-readable string which is rendered less prominently on a separate line in places where the task's name is displayed. Supports rendering of {@link ThemeIcon theme icons} via the $(<name>)-syntax.
getter/setter pair
execution ↔ Object

Available on Task, provided by the Task$Typings extension

The task's execution engine
getter/setter pair
group ↔ TaskGroup

Available on Task, provided by the Task$Typings extension

The task group this tasks belongs to. See TaskGroup for a predefined set of available groups. Defaults to undefined meaning that the task doesn't belong to any special group.
getter/setter pair
isBackground ↔ bool

Available on Task, provided by the Task$Typings extension

Whether the task is a background task or not.
getter/setter pair
name ↔ String

Available on Task, provided by the Task$Typings extension

The task's name
getter/setter pair
presentationOptions ↔ TaskPresentationOptions

Available on Task, provided by the Task$Typings extension

The presentation options. Defaults to an empty literal.
getter/setter pair
problemMatchers ↔ List<String>

Available on Task, provided by the Task$Typings extension

The problem matchers attached to the task. Defaults to an empty array.
getter/setter pair
runOptions ↔ RunOptions

Available on Task, provided by the Task$Typings extension

Run options for the task
getter/setter pair
scope → dynamic

Available on Task, provided by the Task$Typings extension

The task's scope.
no setter
source ↔ String

Available on Task, provided by the Task$Typings extension

A human-readable string describing the source of this shell task, e.g. 'gulp' or 'npm'. Supports rendering of {@link ThemeIcon theme icons} via the $(<name>)-syntax.
getter/setter pair