TaskPresentationOptions class

Controls how the task is presented in the UI.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

TaskPresentationOptions({TaskRevealKind? reveal, bool? echo, bool? focus, TaskPanelKind? panel, bool? showReuseMessage, bool? clear, bool? close})
factory

Properties

clear ↔ bool?

Available on TaskPresentationOptions, provided by the TaskPresentationOptions$Typings extension

Controls whether the terminal is cleared before executing the task.
getter/setter pair
close ↔ bool?

Available on TaskPresentationOptions, provided by the TaskPresentationOptions$Typings extension

Controls whether the terminal is closed after executing the task.
getter/setter pair
echo ↔ bool?

Available on TaskPresentationOptions, provided by the TaskPresentationOptions$Typings extension

Controls whether the command associated with the task is echoed in the user interface.
getter/setter pair
focus ↔ bool?

Available on TaskPresentationOptions, provided by the TaskPresentationOptions$Typings extension

Controls whether the panel showing the task output is taking focus.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
panel ↔ TaskPanelKind?

Available on TaskPresentationOptions, provided by the TaskPresentationOptions$Typings extension

Controls if the task panel is used for this task only (dedicated), shared between tasks (shared) or if a new panel is created on every task execution (new). Defaults to TaskInstanceKind.Shared
getter/setter pair
reveal ↔ TaskRevealKind?

Available on TaskPresentationOptions, provided by the TaskPresentationOptions$Typings extension

Controls whether the task output is reveal in the user interface. Defaults to RevealKind.Always.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showReuseMessage ↔ bool?

Available on TaskPresentationOptions, provided by the TaskPresentationOptions$Typings extension

Controls whether to show the "Terminal will be reused by tasks, press any key to close it" message.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited