TextDocumentContentProvider class

A text document content provider allows to add readonly documents to the editor, such as source from a dll or generated html from md.

Content providers are {@link workspace.registerTextDocumentContentProviderregistered} for a {@link Uri.schemeuri-scheme}. When a uri with that scheme is to be {@link workspace.openTextDocumentloaded} the content provider is asked.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

TextDocumentContentProvider({Event<Uri>? onDidChange, FutureOr<String> provideTextDocumentContent(Uri, CancellationToken)?})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
onDidChange ↔ Event<Uri>?

Available on TextDocumentContentProvider, provided by the TextDocumentContentProvider$Typings extension

An event to signal a resource has changed.
getter/setter pair
provideTextDocumentContent ↔ FutureOr<String> Function(Uri, CancellationToken)

Available on TextDocumentContentProvider, provided by the TextDocumentContentProvider$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited