TextEditorViewColumnChangeEvent class

Represents an event describing the change of a {@link TextEditor.viewColumntext editor's view column}.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

TextEditorViewColumnChangeEvent({TextEditor? textEditor, ViewColumn? viewColumn})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textEditor → TextEditor

Available on TextEditorViewColumnChangeEvent, provided by the TextEditorViewColumnChangeEvent$Typings extension

The {@link TextEditortext editor} for which the view column has changed.
no setter
viewColumn → ViewColumn

Available on TextEditorViewColumnChangeEvent, provided by the TextEditorViewColumnChangeEvent$Typings extension

The new value for the {@link TextEditor.viewColumntext editor's view column}.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited