TextEditorVisibleRangesChangeEvent class

Represents an event describing the change in a {@link TextEditor.visibleRangestext editor's visible ranges}.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

TextEditorVisibleRangesChangeEvent({TextEditor? textEditor, List<Range>? visibleRanges})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textEditor → TextEditor

Available on TextEditorVisibleRangesChangeEvent, provided by the TextEditorVisibleRangesChangeEvent$Typings extension

The {@link TextEditortext editor} for which the visible ranges have changed.
no setter
visibleRanges → List<Range>

Available on TextEditorVisibleRangesChangeEvent, provided by the TextEditorVisibleRangesChangeEvent$Typings extension

The new value for the {@link TextEditor.visibleRangestext editor's visible ranges}.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited