Webview class

Displays html content, similarly to an iframe.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

Webview({WebviewOptions? options, String? html, Event? onDidReceiveMessage, String? cspSource, Future postMessage([dynamic])?, Uri asWebviewUri(Uri)?})
factory

Properties

asWebviewUri ↔ Uri Function(Uri)

Available on Webview, provided by the Webview$Typings extension

getter/setter pair
cspSource → String

Available on Webview, provided by the Webview$Typings extension

Content security policy source for webview resources.
no setter
hashCode → int
The hash code for this object.
no setterinherited
html ↔ String

Available on Webview, provided by the Webview$Typings extension

HTML contents of the webview.
getter/setter pair
onDidReceiveMessage → Event

Available on Webview, provided by the Webview$Typings extension

Fired when the webview content posts a message.
no setter
options ↔ WebviewOptions

Available on Webview, provided by the Webview$Typings extension

Content settings for the webview.
getter/setter pair
postMessage ↔ Future Function([dynamic])

Available on Webview, provided by the Webview$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited