WebviewOptions$Typings extension

on

Properties

enableCommandUris → Object?

Available on WebviewOptions, provided by the WebviewOptions$Typings extension

Controls whether command uris are enabled in webview content or not.
no setter
enableForms → bool?

Available on WebviewOptions, provided by the WebviewOptions$Typings extension

Controls whether forms are enabled in the webview content or not.
no setter
enableScripts → bool?

Available on WebviewOptions, provided by the WebviewOptions$Typings extension

Controls whether scripts are enabled in the webview content or not.
no setter
localResourceRoots → List<Uri>?

Available on WebviewOptions, provided by the WebviewOptions$Typings extension

Root paths from which the webview can load local (filesystem) resources using uris from asWebviewUri
no setter
portMapping → List<WebviewPortMapping>?

Available on WebviewOptions, provided by the WebviewOptions$Typings extension

Mappings of localhost ports used inside the webview.
no setter