WebviewOptions class

Content settings for a webview.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

WebviewOptions({bool? enableScripts, bool? enableForms, Object? enableCommandUris, List<Uri>? localResourceRoots, List<WebviewPortMapping>? portMapping})
factory

Properties

enableCommandUris → Object?

Available on WebviewOptions, provided by the WebviewOptions$Typings extension

Controls whether command uris are enabled in webview content or not.
no setter
enableForms → bool?

Available on WebviewOptions, provided by the WebviewOptions$Typings extension

Controls whether forms are enabled in the webview content or not.
no setter
enableScripts → bool?

Available on WebviewOptions, provided by the WebviewOptions$Typings extension

Controls whether scripts are enabled in the webview content or not.
no setter
hashCode → int
The hash code for this object.
no setterinherited
localResourceRoots → List<Uri>?

Available on WebviewOptions, provided by the WebviewOptions$Typings extension

Root paths from which the webview can load local (filesystem) resources using uris from asWebviewUri
no setter
portMapping → List<WebviewPortMapping>?

Available on WebviewOptions, provided by the WebviewOptions$Typings extension

Mappings of localhost ports used inside the webview.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited