WebviewPanelOptions class

Content settings for a webview panel.

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

WebviewPanelOptions({bool? enableFindWidget, bool? retainContextWhenHidden})
factory

Properties

enableFindWidget → bool?

Available on WebviewPanelOptions, provided by the WebviewPanelOptions$Typings extension

Controls if the find widget is enabled in the panel.
no setter
hashCode → int
The hash code for this object.
no setterinherited
retainContextWhenHidden → bool?

Available on WebviewPanelOptions, provided by the WebviewPanelOptions$Typings extension

Controls if the webview panel's content (iframe) is kept around even when the panel is no longer visible.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited