Body class

Implementers
Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

Body({ReadableStream<Uint8List>? body, bool? bodyUsed, Future<ByteBuffer> arrayBuffer()?, Future<Blob> blob()?, Future<FormData> formData()?, Future json()?, Future<String> text()?})
factory

Properties

arrayBuffer ↔ Future<ByteBuffer> Function()

Available on Body, provided by the Body$Typings extension

getter/setter pair
blob ↔ Future<Blob> Function()

Available on Body, provided by the Body$Typings extension

getter/setter pair
body → ReadableStream<Uint8List>?

Available on Body, provided by the Body$Typings extension

MDN Reference
no setter
bodyUsed → bool

Available on Body, provided by the Body$Typings extension

MDN Reference
no setter
formData ↔ Future<FormData> Function()

Available on Body, provided by the Body$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
json ↔ Future Function()

Available on Body, provided by the Body$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ Future<String> Function()

Available on Body, provided by the Body$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited