ByteLengthQueuingStrategy class

This Streams API interface provides a built-in byte length queuing strategy that can be used when constructing streams.

MDN Reference

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

ByteLengthQueuingStrategy(QueuingStrategyInit init)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
highWaterMark → num

Available on ByteLengthQueuingStrategy, provided by the ByteLengthQueuingStrategy$Typings extension

MDN Reference
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → QueuingStrategySize<ArrayBufferView>

Available on ByteLengthQueuingStrategy, provided by the ByteLengthQueuingStrategy$Typings extension

MDN Reference
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited