CSSKeywordValue class

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

CSSKeywordValue(String value)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toString$ ↔ String Function()

Available on CSSStyleValue, provided by the CSSStyleValue$Typings extension

getter/setter pair
value ↔ String

Available on CSSKeywordValue, provided by the CSSKeywordValue$Typings extension

MDN Reference
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited