CSSNumericArray class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

CSSNumericArray()
factory

Properties

entries ↔ IterableIterator<(num, CSSNumericValue)> Function()

Available on CSSNumericArray, provided by the CSSNumericArray$Typings extension

getter/setter pair
forEach ↔ void Function(void (CSSNumericValue, num, CSSNumericArray), [dynamic])

Available on CSSNumericArray, provided by the CSSNumericArray$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keys ↔ IterableIterator<num> Function()

Available on CSSNumericArray, provided by the CSSNumericArray$Typings extension

getter/setter pair
length → num

Available on CSSNumericArray, provided by the CSSNumericArray$Typings extension

MDN Reference
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values ↔ IterableIterator<CSSNumericValue> Function()

Available on CSSNumericArray, provided by the CSSNumericArray$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](num index) → CSSNumericValue

Available on CSSNumericArray, provided by the CSSNumericArray$Typings extension

operator []=(num index, CSSNumericValue value) → void

Available on CSSNumericArray, provided by the CSSNumericArray$Typings extension