CSSNumericType class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

CSSNumericType({num? angle, num? flex, num? frequency, num? length, num? percent, CSSNumericBaseType? percentHint, num? resolution, num? time})
factory

Properties

angle ↔ num?

Available on CSSNumericType, provided by the CSSNumericType$Typings extension

getter/setter pair
flex ↔ num?

Available on CSSNumericType, provided by the CSSNumericType$Typings extension

getter/setter pair
frequency ↔ num?

Available on CSSNumericType, provided by the CSSNumericType$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
length ↔ num?

Available on CSSNumericType, provided by the CSSNumericType$Typings extension

getter/setter pair
percent ↔ num?

Available on CSSNumericType, provided by the CSSNumericType$Typings extension

getter/setter pair
percentHint ↔ CSSNumericBaseType?

Available on CSSNumericType, provided by the CSSNumericType$Typings extension

getter/setter pair
resolution ↔ num?

Available on CSSNumericType, provided by the CSSNumericType$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
time ↔ num?

Available on CSSNumericType, provided by the CSSNumericType$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited