CSSRotate class

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

CSSRotate.$1()
factory
CSSRotate.$2(CSSNumericValue angle)
factory
CSSRotate.$3(Object x, Object y, Object z, CSSNumericValue angle)
factory

Properties

angle ↔ CSSNumericValue

Available on CSSRotate, provided by the CSSRotate$Typings extension

MDN Reference
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
is2D ↔ bool

Available on CSSTransformComponent, provided by the CSSTransformComponent$Typings extension

MDN Reference
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toMatrix ↔ DOMMatrix Function()

Available on CSSTransformComponent, provided by the CSSTransformComponent$Typings extension

getter/setter pair
toString$ ↔ String Function()

Available on CSSTransformComponent, provided by the CSSTransformComponent$Typings extension

getter/setter pair
x ↔ Object

Available on CSSRotate, provided by the CSSRotate$Typings extension

MDN Reference
getter/setter pair
y ↔ Object

Available on CSSRotate, provided by the CSSRotate$Typings extension

MDN Reference
getter/setter pair
z ↔ Object

Available on CSSRotate, provided by the CSSRotate$Typings extension

MDN Reference
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited