CacheStorage class

The storage for Cache objects. Available only in secure contexts.

MDN Reference

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

CacheStorage()
factory

Properties

delete ↔ Future<bool> Function(String)

Available on CacheStorage, provided by the CacheStorage$Typings extension

getter/setter pair
has ↔ Future<bool> Function(String)

Available on CacheStorage, provided by the CacheStorage$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keys ↔ Future<List<String>> Function()

Available on CacheStorage, provided by the CacheStorage$Typings extension

getter/setter pair
match ↔ Future<Response?> Function(Object, [MultiCacheQueryOptions?])

Available on CacheStorage, provided by the CacheStorage$Typings extension

getter/setter pair
open ↔ Future<Cache> Function(String)

Available on CacheStorage, provided by the CacheStorage$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited