Client class

The Client interface represents an executable context such as a Worker, or a SharedWorker. Window clients are represented by the more-specific WindowClient. You can get Client/WindowClient objects from methods such as Clients.matchAll() and Clients.get().

MDN Reference

Implementers
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

Client()
factory

Properties

frameType → FrameType

Available on Client, provided by the Client$Typings extension

MDN Reference
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String

Available on Client, provided by the Client$Typings extension

MDN Reference
no setter
postMessage → ({void Function(List<Object> transfer, [dynamic message]) $1, void Function([dynamic message, StructuredSerializeOptions? options]) $2})

Available on Client, provided by the Client$Typings extension

Overload accessor: $1, $2
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ClientTypes

Available on Client, provided by the Client$Typings extension

MDN Reference
no setter
url → String

Available on Client, provided by the Client$Typings extension

MDN Reference
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited