EncodedVideoChunk class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

EncodedVideoChunk(EncodedVideoChunkInit init)
factory

Properties

byteLength → num

Available on EncodedVideoChunk, provided by the EncodedVideoChunk$Typings extension

MDN Reference
no setter
copyTo ↔ void Function(Object)

Available on EncodedVideoChunk, provided by the EncodedVideoChunk$Typings extension

getter/setter pair
duration → num?

Available on EncodedVideoChunk, provided by the EncodedVideoChunk$Typings extension

MDN Reference
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → num

Available on EncodedVideoChunk, provided by the EncodedVideoChunk$Typings extension

MDN Reference
no setter
type → EncodedVideoChunkType

Available on EncodedVideoChunk, provided by the EncodedVideoChunk$Typings extension

MDN Reference
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited