EventSource class

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

EventSource(Object url, [EventSourceInit? eventSourceInitDict])
factory

Properties

addEventListener → ({void Function<K$>(EventSourceEventMap<K$> type, dynamic listener(K$), [Object? options]) $1, void Function(String type, dynamic listener(MessageEvent), [Object? options]) $2, void Function(String type, Object listener, [Object? options]) $3})

Available on EventSource, provided by the EventSource$Typings extension

Overload accessor: $1, $2, $3
no setter
addEventListener ↔ void Function(String, [Object?, Object?])

Available on EventTarget, provided by the EventTarget$Typings extension

getter/setter pair
close ↔ void Function()

Available on EventSource, provided by the EventSource$Typings extension

getter/setter pair
closed → num

Available on EventSource, provided by the EventSource$Typings extension

no setter
connecting → num

Available on EventSource, provided by the EventSource$Typings extension

no setter
dispatchEvent ↔ bool Function(Event)

Available on EventTarget, provided by the EventTarget$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
onerror ↔ dynamic Function(Event)?

Available on EventSource, provided by the EventSource$Typings extension

MDN Reference
getter/setter pair
onmessage ↔ dynamic Function(MessageEvent)?

Available on EventSource, provided by the EventSource$Typings extension

MDN Reference
getter/setter pair
onopen ↔ dynamic Function(Event)?

Available on EventSource, provided by the EventSource$Typings extension

MDN Reference
getter/setter pair
open → num

Available on EventSource, provided by the EventSource$Typings extension

no setter
readyState → num

Available on EventSource, provided by the EventSource$Typings extension

Returns the state of this EventSource object's connection. It can have the values described below.
no setter
removeEventListener → ({void Function<K$>(EventSourceEventMap<K$> type, dynamic listener(K$), [Object? options]) $1, void Function(String type, dynamic listener(MessageEvent), [Object? options]) $2, void Function(String type, Object listener, [Object? options]) $3})

Available on EventSource, provided by the EventSource$Typings extension

Overload accessor: $1, $2, $3
no setter
removeEventListener ↔ void Function(String, [Object?, Object?])

Available on EventTarget, provided by the EventTarget$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String

Available on EventSource, provided by the EventSource$Typings extension

Returns the URL providing the event stream.
no setter
withCredentials → bool

Available on EventSource, provided by the EventSource$Typings extension

Returns true if the credentials mode for connection requests to the URL providing the event stream is set to "include", and false otherwise.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

closed → num
no setter
connecting → num
no setter
open → num
no setter