File class

Provides information about files and allows JavaScript in a web page to access their content.

MDN Reference

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

File(List<Object> fileBits, String fileName, [FilePropertyBag? options])
factory

Properties

arrayBuffer ↔ Future<ByteBuffer> Function()

Available on Blob, provided by the Blob$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastModified → num

Available on File, provided by the File$Typings extension

MDN Reference
no setter
name → String

Available on File, provided by the File$Typings extension

MDN Reference
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → num

Available on Blob, provided by the Blob$Typings extension

MDN Reference
no setter
slice ↔ Blob Function([num?, num?, String?])

Available on Blob, provided by the Blob$Typings extension

getter/setter pair
stream ↔ ReadableStream<Uint8List> Function()

Available on Blob, provided by the Blob$Typings extension

getter/setter pair
text ↔ Future<String> Function()

Available on Blob, provided by the Blob$Typings extension

getter/setter pair
type → String

Available on Blob, provided by the Blob$Typings extension

MDN Reference
no setter
webkitRelativePath → String

Available on File, provided by the File$Typings extension

MDN Reference
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited