FilePropertyBag class

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

FilePropertyBag({num? lastModified, EndingType? endings, String? type})
factory

Properties

endings ↔ EndingType?

Available on BlobPropertyBag, provided by the BlobPropertyBag$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastModified ↔ num?

Available on FilePropertyBag, provided by the FilePropertyBag$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?

Available on BlobPropertyBag, provided by the BlobPropertyBag$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited