FileSystemFileHandle class

Available only in secure contexts.

MDN Reference

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

FileSystemFileHandle()
factory

Properties

createSyncAccessHandle ↔ Future<FileSystemSyncAccessHandle> Function()

Available on FileSystemFileHandle, provided by the FileSystemFileHandle$Typings extension

getter/setter pair
createWritable ↔ Future<FileSystemWritableFileStream> Function([FileSystemCreateWritableOptions?])

Available on FileSystemFileHandle, provided by the FileSystemFileHandle$Typings extension

getter/setter pair
getFile ↔ Future<File> Function()

Available on FileSystemFileHandle, provided by the FileSystemFileHandle$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isSameEntry ↔ Future<bool> Function(FileSystemHandle)

Available on FileSystemHandle, provided by the FileSystemHandle$Typings extension

getter/setter pair
kind → String

Available on FileSystemFileHandle, provided by the FileSystemFileHandle$Typings extension

MDN Reference
no setter
kind → FileSystemHandleKind

Available on FileSystemHandle, provided by the FileSystemHandle$Typings extension

MDN Reference
no setter
name → String

Available on FileSystemHandle, provided by the FileSystemHandle$Typings extension

MDN Reference
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

kind → String
MDN Reference
no setter