FormData class

Provides a way to easily construct a set of key/value pairs representing form fields and their values, which can then be easily sent using the XMLHttpRequest.send() method. It uses the same format a form would use if the encoding type were set to "multipart/form-data".

MDN Reference

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

FormData()
factory

Properties

append → ({void Function(String name, Object value) $1, void Function(String name, String value) $2, void Function(String name, Blob blobValue, [String? filename]) $3})

Available on FormData, provided by the FormData$Typings extension

Overload accessor: $1, $2, $3
no setter
delete ↔ void Function(String)

Available on FormData, provided by the FormData$Typings extension

getter/setter pair
entries ↔ IterableIterator<(String, Object)> Function()

Available on FormData, provided by the FormData$Typings extension

getter/setter pair
forEach ↔ void Function(void (Object, String, FormData), [dynamic])

Available on FormData, provided by the FormData$Typings extension

getter/setter pair
get ↔ Object? Function(String)

Available on FormData, provided by the FormData$Typings extension

getter/setter pair
getAll ↔ List<Object> Function(String)

Available on FormData, provided by the FormData$Typings extension

getter/setter pair
has ↔ bool Function(String)

Available on FormData, provided by the FormData$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keys ↔ IterableIterator<String> Function()

Available on FormData, provided by the FormData$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
set → ({void Function(String name, Object value) $1, void Function(String name, String value) $2, void Function(String name, Blob blobValue, [String? filename]) $3})

Available on FormData, provided by the FormData$Typings extension

Overload accessor: $1, $2, $3
no setter
values ↔ IterableIterator<Object> Function()

Available on FormData, provided by the FormData$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited