IDBCursorWithValue class

This IndexedDB API interface represents a cursor for traversing or iterating over multiple records in a database. It is the same as the IDBCursor, except that it includes the value property.

MDN Reference

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

IDBCursorWithValue()
factory

Properties

advance ↔ void Function(num handle)

Available on IDBCursor, provided by the IDBCursor$Typings extension

getter/setter pair
continue$ ↔ void Function([Object?])

Available on IDBCursor, provided by the IDBCursor$Typings extension

getter/setter pair
continuePrimaryKey ↔ void Function(Object, Object)

Available on IDBCursor, provided by the IDBCursor$Typings extension

getter/setter pair
delete ↔ IDBRequest Function()

Available on IDBCursor, provided by the IDBCursor$Typings extension

getter/setter pair
direction → IDBCursorDirection

Available on IDBCursor, provided by the IDBCursor$Typings extension

Returns the direction ("next", "nextunique", "prev" or "prevunique") of the cursor.
no setter
hashCode → int
The hash code for this object.
no setterinherited
key → Object

Available on IDBCursor, provided by the IDBCursor$Typings extension

Returns the key of the cursor. Throws a "InvalidStateError" DOMException if the cursor is advancing or is finished.
no setter
primaryKey → Object

Available on IDBCursor, provided by the IDBCursor$Typings extension

Returns the effective key of the cursor. Throws a "InvalidStateError" DOMException if the cursor is advancing or is finished.
no setter
request → IDBRequest

Available on IDBCursor, provided by the IDBCursor$Typings extension

MDN Reference
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → Object

Available on IDBCursor, provided by the IDBCursor$Typings extension

Returns the IDBObjectStore or IDBIndex the cursor was opened from.
no setter
update ↔ IDBRequest<Object> Function([dynamic])

Available on IDBCursor, provided by the IDBCursor$Typings extension

getter/setter pair
value → dynamic

Available on IDBCursorWithValue, provided by the IDBCursorWithValue$Typings extension

Returns the cursor's current value.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited