IDBKeyRange class

A key range can be a single value or a range with upper and lower bounds or endpoints. If the key range has both upper and lower bounds, then it is bounded; if it has no bounds, it is unbounded. A bounded key range can either be open (the endpoints are excluded) or closed (the endpoints are included). To retrieve all keys within a certain range, you can use the following code constructs:

MDN Reference

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

IDBKeyRange()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
includes ↔ bool Function([dynamic])

Available on IDBKeyRange, provided by the IDBKeyRange$Typings extension

getter/setter pair
lower → dynamic

Available on IDBKeyRange, provided by the IDBKeyRange$Typings extension

Returns lower bound, or undefined if none.
no setter
lowerOpen → bool

Available on IDBKeyRange, provided by the IDBKeyRange$Typings extension

Returns true if the lower open flag is set, and false otherwise.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
upper → dynamic

Available on IDBKeyRange, provided by the IDBKeyRange$Typings extension

Returns upper bound, or undefined if none.
no setter
upperOpen → bool

Available on IDBKeyRange, provided by the IDBKeyRange$Typings extension

Returns true if the upper open flag is set, and false otherwise.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

bound ↔ IDBKeyRange Function([dynamic, dynamic, bool?, bool?])
getter/setter pair
lowerBound ↔ IDBKeyRange Function([dynamic, bool?])
getter/setter pair
only ↔ IDBKeyRange Function([dynamic])
getter/setter pair
upperBound ↔ IDBKeyRange Function([dynamic, bool?])
getter/setter pair