IDBObjectStore$Typings extension

on

Properties

add ↔ IDBRequest<Object> Function([dynamic, Object?])

Available on IDBObjectStore, provided by the IDBObjectStore$Typings extension

getter/setter pair
autoIncrement → bool

Available on IDBObjectStore, provided by the IDBObjectStore$Typings extension

Returns true if the store has a key generator, and false otherwise.
no setter
clear ↔ IDBRequest Function()

Available on IDBObjectStore, provided by the IDBObjectStore$Typings extension

getter/setter pair
count ↔ IDBRequest<num> Function([Object?])

Available on IDBObjectStore, provided by the IDBObjectStore$Typings extension

getter/setter pair
createIndex → ({IDBIndex Function(String name, Object keyPath, [IDBIndexParameters? options]) $1, IDBIndex Function(String name, Object keyPath, [IDBIndexParameters? options]) $2})

Available on IDBObjectStore, provided by the IDBObjectStore$Typings extension

Overload accessor: $1, $2
no setter
delete ↔ IDBRequest Function(Object)

Available on IDBObjectStore, provided by the IDBObjectStore$Typings extension

getter/setter pair
deleteIndex ↔ void Function(String)

Available on IDBObjectStore, provided by the IDBObjectStore$Typings extension

getter/setter pair
get ↔ IDBRequest Function(Object)

Available on IDBObjectStore, provided by the IDBObjectStore$Typings extension

getter/setter pair
getAll ↔ IDBRequest<List> Function([dynamic, num?])

Available on IDBObjectStore, provided by the IDBObjectStore$Typings extension

getter/setter pair
getAllKeys ↔ IDBRequest<List<Object>> Function([dynamic, num?])

Available on IDBObjectStore, provided by the IDBObjectStore$Typings extension

getter/setter pair
getKey ↔ IDBRequest<Object?> Function(Object)

Available on IDBObjectStore, provided by the IDBObjectStore$Typings extension

getter/setter pair
index ↔ IDBIndex Function(String)

Available on IDBObjectStore, provided by the IDBObjectStore$Typings extension

getter/setter pair
indexNames → DOMStringList

Available on IDBObjectStore, provided by the IDBObjectStore$Typings extension

Returns a list of the names of indexes in the store.
no setter
keyPath → Object

Available on IDBObjectStore, provided by the IDBObjectStore$Typings extension

Returns the key path of the store, or null if none.
no setter
name ↔ String

Available on IDBObjectStore, provided by the IDBObjectStore$Typings extension

Returns the name of the store.
getter/setter pair
openCursor ↔ IDBRequest<IDBCursorWithValue?> Function([dynamic, IDBCursorDirection?])

Available on IDBObjectStore, provided by the IDBObjectStore$Typings extension

getter/setter pair
openKeyCursor ↔ IDBRequest<IDBCursor?> Function([dynamic, IDBCursorDirection?])

Available on IDBObjectStore, provided by the IDBObjectStore$Typings extension

getter/setter pair
put ↔ IDBRequest<Object> Function([dynamic, Object?])

Available on IDBObjectStore, provided by the IDBObjectStore$Typings extension

getter/setter pair
transaction → IDBTransaction

Available on IDBObjectStore, provided by the IDBObjectStore$Typings extension

Returns the associated transaction.
no setter