IDBTransaction class

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

IDBTransaction()
factory

Properties

abort ↔ void Function()

Available on IDBTransaction, provided by the IDBTransaction$Typings extension

getter/setter pair
addEventListener ↔ void Function(String, [Object?, Object?])

Available on EventTarget, provided by the EventTarget$Typings extension

getter/setter pair
addEventListener → ({void Function<K$>(IDBTransactionEventMap<K$> type, dynamic listener(K$), [Object? options]) $1, void Function(String type, Object listener, [Object? options]) $2})

Available on IDBTransaction, provided by the IDBTransaction$Typings extension

Overload accessor: $1, $2
no setter
commit ↔ void Function()

Available on IDBTransaction, provided by the IDBTransaction$Typings extension

getter/setter pair
db → IDBDatabase

Available on IDBTransaction, provided by the IDBTransaction$Typings extension

Returns the transaction's connection.
no setter
dispatchEvent ↔ bool Function(Event)

Available on EventTarget, provided by the EventTarget$Typings extension

getter/setter pair
durability → IDBTransactionDurability

Available on IDBTransaction, provided by the IDBTransaction$Typings extension

MDN Reference
no setter
error → DOMException?

Available on IDBTransaction, provided by the IDBTransaction$Typings extension

If the transaction was aborted, returns the error (a DOMException) providing the reason.
no setter
hashCode → int
The hash code for this object.
no setterinherited
mode → IDBTransactionMode

Available on IDBTransaction, provided by the IDBTransaction$Typings extension

Returns the mode the transaction was created with ("readonly" or "readwrite"), or "versionchange" for an upgrade transaction.
no setter
objectStore ↔ IDBObjectStore Function(String)

Available on IDBTransaction, provided by the IDBTransaction$Typings extension

getter/setter pair
objectStoreNames → DOMStringList

Available on IDBTransaction, provided by the IDBTransaction$Typings extension

Returns a list of the names of object stores in the transaction's scope. For an upgrade transaction this is all object stores in the database.
no setter
onabort ↔ dynamic Function(Event)?

Available on IDBTransaction, provided by the IDBTransaction$Typings extension

MDN Reference
getter/setter pair
oncomplete ↔ dynamic Function(Event)?

Available on IDBTransaction, provided by the IDBTransaction$Typings extension

MDN Reference
getter/setter pair
onerror ↔ dynamic Function(Event)?

Available on IDBTransaction, provided by the IDBTransaction$Typings extension

MDN Reference
getter/setter pair
removeEventListener ↔ void Function(String, [Object?, Object?])

Available on EventTarget, provided by the EventTarget$Typings extension

getter/setter pair
removeEventListener → ({void Function<K$>(IDBTransactionEventMap<K$> type, dynamic listener(K$), [Object? options]) $1, void Function(String type, Object listener, [Object? options]) $2})

Available on IDBTransaction, provided by the IDBTransaction$Typings extension

Overload accessor: $1, $2
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited