MediaEncodingConfiguration class

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Properties

audio ↔ AudioConfiguration?

Available on MediaConfiguration, provided by the MediaConfiguration$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ MediaEncodingType

Available on MediaEncodingConfiguration, provided by the MediaEncodingConfiguration$Typings extension

getter/setter pair
video ↔ VideoConfiguration?

Available on MediaConfiguration, provided by the MediaConfiguration$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited