NotificationEventInit class

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

NotificationEventInit({String? action, Notification? notification})
factory

Properties

action ↔ String?

Available on NotificationEventInit, provided by the NotificationEventInit$Typings extension

getter/setter pair
bubbles ↔ bool?

Available on EventInit, provided by the EventInit$Typings extension

getter/setter pair
cancelable ↔ bool?

Available on EventInit, provided by the EventInit$Typings extension

getter/setter pair
composed ↔ bool?

Available on EventInit, provided by the EventInit$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
notification ↔ Notification

Available on NotificationEventInit, provided by the NotificationEventInit$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited