NotificationOptions class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

NotificationOptions({List<NotificationAction>? actions, String? badge, String? body, dynamic data, NotificationDirection? dir, String? icon, String? image, String? lang, bool? renotify, bool? requireInteraction, bool? silent, String? tag, int? timestamp, Object? vibrate})
factory

Properties

actions ↔ List<NotificationAction>?

Available on NotificationOptions, provided by the NotificationOptions$Typings extension

getter/setter pair
badge ↔ String?

Available on NotificationOptions, provided by the NotificationOptions$Typings extension

getter/setter pair
body ↔ String?

Available on NotificationOptions, provided by the NotificationOptions$Typings extension

getter/setter pair
data ↔ dynamic

Available on NotificationOptions, provided by the NotificationOptions$Typings extension

getter/setter pair
dir ↔ NotificationDirection?

Available on NotificationOptions, provided by the NotificationOptions$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
icon ↔ String?

Available on NotificationOptions, provided by the NotificationOptions$Typings extension

getter/setter pair
image ↔ String?

Available on NotificationOptions, provided by the NotificationOptions$Typings extension

getter/setter pair
lang ↔ String?

Available on NotificationOptions, provided by the NotificationOptions$Typings extension

getter/setter pair
renotify ↔ bool?

Available on NotificationOptions, provided by the NotificationOptions$Typings extension

getter/setter pair
requireInteraction ↔ bool?

Available on NotificationOptions, provided by the NotificationOptions$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
silent ↔ bool?

Available on NotificationOptions, provided by the NotificationOptions$Typings extension

getter/setter pair
tag ↔ String?

Available on NotificationOptions, provided by the NotificationOptions$Typings extension

getter/setter pair
timestamp ↔ int?

Available on NotificationOptions, provided by the NotificationOptions$Typings extension

getter/setter pair
vibrate ↔ Object?

Available on NotificationOptions, provided by the NotificationOptions$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited