PerformanceMeasure class

PerformanceMeasure is an abstract interface for PerformanceEntry objects with an entryType of "measure". Entries of this type are created by calling performance.measure() to add a named DOMHighResTimeStamp (the measure) between two marks to the browser's performance timeline.

MDN Reference

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

PerformanceMeasure()
factory

Properties

detail → dynamic

Available on PerformanceMeasure, provided by the PerformanceMeasure$Typings extension

MDN Reference
no setter
duration → num

Available on PerformanceEntry, provided by the PerformanceEntry$Typings extension

MDN Reference
no setter
entryType → String

Available on PerformanceEntry, provided by the PerformanceEntry$Typings extension

MDN Reference
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String

Available on PerformanceEntry, provided by the PerformanceEntry$Typings extension

MDN Reference
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → num

Available on PerformanceEntry, provided by the PerformanceEntry$Typings extension

MDN Reference
no setter
toJSON ↔ dynamic Function()

Available on PerformanceEntry, provided by the PerformanceEntry$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited