PushManager class

This Push API interface provides a way to receive notifications from third-party servers as well as request URLs for push notifications. Available only in secure contexts.

MDN Reference

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

PushManager()
factory

Properties

getSubscription ↔ Future<PushSubscription?> Function()

Available on PushManager, provided by the PushManager$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
permissionState ↔ Future<PermissionState> Function([PushSubscriptionOptionsInit?])

Available on PushManager, provided by the PushManager$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscribe ↔ Future<PushSubscription> Function([PushSubscriptionOptionsInit?])

Available on PushManager, provided by the PushManager$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

supportedContentEncodings → ReadonlyArray<String>
MDN Reference
no setter