PushMessageData class

This Push API interface provides methods which let you retrieve the push data sent by a server in various formats. Available only in secure contexts.

MDN Reference

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

PushMessageData()
factory

Properties

arrayBuffer ↔ ByteBuffer Function()

Available on PushMessageData, provided by the PushMessageData$Typings extension

getter/setter pair
blob ↔ Blob Function()

Available on PushMessageData, provided by the PushMessageData$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
json ↔ dynamic Function()

Available on PushMessageData, provided by the PushMessageData$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String Function()

Available on PushMessageData, provided by the PushMessageData$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited