PushSubscription class

This Push API interface provides a subcription's URL endpoint and allows unsubscription from a push service. Available only in secure contexts.

MDN Reference

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

PushSubscription()
factory

Properties

endpoint → String

Available on PushSubscription, provided by the PushSubscription$Typings extension

MDN Reference
no setter
expirationTime → int?

Available on PushSubscription, provided by the PushSubscription$Typings extension

MDN Reference
no setter
getKey ↔ ByteBuffer? Function(PushEncryptionKeyName)

Available on PushSubscription, provided by the PushSubscription$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
options → PushSubscriptionOptions

Available on PushSubscription, provided by the PushSubscription$Typings extension

MDN Reference
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJSON ↔ PushSubscriptionJSON Function()

Available on PushSubscription, provided by the PushSubscription$Typings extension

getter/setter pair
unsubscribe ↔ Future<bool> Function()

Available on PushSubscription, provided by the PushSubscription$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited