PushSubscriptionJSON class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

PushSubscriptionJSON({String? endpoint, int? expirationTime, dynamic keys})
factory

Properties

endpoint ↔ String?

Available on PushSubscriptionJSON, provided by the PushSubscriptionJSON$Typings extension

getter/setter pair
expirationTime ↔ int?

Available on PushSubscriptionJSON, provided by the PushSubscriptionJSON$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keys ↔ dynamic

Available on PushSubscriptionJSON, provided by the PushSubscriptionJSON$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited