Report class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

Report()
factory

Properties

body → ReportBody?

Available on Report, provided by the Report$Typings extension

MDN Reference
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJSON ↔ dynamic Function()

Available on Report, provided by the Report$Typings extension

getter/setter pair
type → String

Available on Report, provided by the Report$Typings extension

MDN Reference
no setter
url → String

Available on Report, provided by the Report$Typings extension

MDN Reference
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited