RequestInit$Typings extension

on

Properties

body ↔ Object?

Available on RequestInit, provided by the RequestInit$Typings extension

A BodyInit object or null to set request's body.
getter/setter pair
cache ↔ RequestCache?

Available on RequestInit, provided by the RequestInit$Typings extension

A string indicating how the request will interact with the browser's cache to set request's cache.
getter/setter pair
credentials ↔ RequestCredentials?

Available on RequestInit, provided by the RequestInit$Typings extension

A string indicating whether credentials will be sent with the request always, never, or only when sent to a same-origin URL. Sets request's credentials.
getter/setter pair
headers ↔ Object?

Available on RequestInit, provided by the RequestInit$Typings extension

A Headers object, an object literal, or an array of two-item arrays to set request's headers.
getter/setter pair
integrity ↔ String?

Available on RequestInit, provided by the RequestInit$Typings extension

A cryptographic hash of the resource to be fetched by request. Sets request's integrity.
getter/setter pair
keepalive ↔ bool?

Available on RequestInit, provided by the RequestInit$Typings extension

A boolean to set request's keepalive.
getter/setter pair
method ↔ String?

Available on RequestInit, provided by the RequestInit$Typings extension

A string to set request's method.
getter/setter pair
mode ↔ RequestMode?

Available on RequestInit, provided by the RequestInit$Typings extension

A string to indicate whether the request will use CORS, or will be restricted to same-origin URLs. Sets request's mode.
getter/setter pair
redirect ↔ RequestRedirect?

Available on RequestInit, provided by the RequestInit$Typings extension

A string indicating whether request follows redirects, results in an error upon encountering a redirect, or returns the redirect (in an opaque fashion). Sets request's redirect.
getter/setter pair
referrer ↔ String?

Available on RequestInit, provided by the RequestInit$Typings extension

A string whose value is a same-origin URL, "about:client", or the empty string, to set request's referrer.
getter/setter pair
referrerPolicy ↔ ReferrerPolicy?

Available on RequestInit, provided by the RequestInit$Typings extension

A referrer policy to set request's referrerPolicy.
getter/setter pair
signal ↔ AbortSignal?

Available on RequestInit, provided by the RequestInit$Typings extension

An AbortSignal to set request's signal.
getter/setter pair
window ↔ dynamic

Available on RequestInit, provided by the RequestInit$Typings extension

Can only be null. Used to disassociate request from any Window.
getter/setter pair