StorageManager class

Available only in secure contexts.

MDN Reference

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

StorageManager()
factory

Properties

estimate ↔ Future<StorageEstimate> Function()

Available on StorageManager, provided by the StorageManager$Typings extension

getter/setter pair
getDirectory ↔ Future<FileSystemDirectoryHandle> Function()

Available on StorageManager, provided by the StorageManager$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
persisted ↔ Future<bool> Function()

Available on StorageManager, provided by the StorageManager$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited