StylePropertyMapReadOnly class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

StylePropertyMapReadOnly()
factory

Properties

entries ↔ IterableIterator<(String, Iterable<CSSStyleValue>)> Function()

Available on StylePropertyMapReadOnly, provided by the StylePropertyMapReadOnly$Typings extension

getter/setter pair
forEach ↔ void Function(void (List<CSSStyleValue>, String, StylePropertyMapReadOnly), [dynamic])

Available on StylePropertyMapReadOnly, provided by the StylePropertyMapReadOnly$Typings extension

getter/setter pair
get ↔ CSSStyleValue? Function(String)

Available on StylePropertyMapReadOnly, provided by the StylePropertyMapReadOnly$Typings extension

getter/setter pair
getAll ↔ List<CSSStyleValue> Function(String)

Available on StylePropertyMapReadOnly, provided by the StylePropertyMapReadOnly$Typings extension

getter/setter pair
has ↔ bool Function(String)

Available on StylePropertyMapReadOnly, provided by the StylePropertyMapReadOnly$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keys ↔ IterableIterator<String> Function()

Available on StylePropertyMapReadOnly, provided by the StylePropertyMapReadOnly$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → num

Available on StylePropertyMapReadOnly, provided by the StylePropertyMapReadOnly$Typings extension

MDN Reference
no setter
values ↔ IterableIterator<Iterable<CSSStyleValue>> Function()

Available on StylePropertyMapReadOnly, provided by the StylePropertyMapReadOnly$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited