TextMetrics class

The dimensions of a piece of text in the canvas, as created by the CanvasRenderingContext2D.measureText() method.

MDN Reference

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

TextMetrics()
factory

Properties

actualBoundingBoxAscent → num

Available on TextMetrics, provided by the TextMetrics$Typings extension

Returns the measurement described below.
no setter
actualBoundingBoxDescent → num

Available on TextMetrics, provided by the TextMetrics$Typings extension

Returns the measurement described below.
no setter
actualBoundingBoxLeft → num

Available on TextMetrics, provided by the TextMetrics$Typings extension

Returns the measurement described below.
no setter
actualBoundingBoxRight → num

Available on TextMetrics, provided by the TextMetrics$Typings extension

Returns the measurement described below.
no setter
fontBoundingBoxAscent → num

Available on TextMetrics, provided by the TextMetrics$Typings extension

Returns the measurement described below.
no setter
fontBoundingBoxDescent → num

Available on TextMetrics, provided by the TextMetrics$Typings extension

Returns the measurement described below.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → num

Available on TextMetrics, provided by the TextMetrics$Typings extension

Returns the measurement described below.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited