UnderlyingSource<R> class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

UnderlyingSource({num? autoAllocateChunkSize, UnderlyingSourceCancelCallback? cancel, UnderlyingSourcePullCallback? pull, UnderlyingSourceStartCallback? start, ReadableStreamType? type})
factory

Properties

autoAllocateChunkSize ↔ num?

Available on UnderlyingSource<R>, provided by the UnderlyingSource$Typings extension

getter/setter pair
cancel ↔ UnderlyingSourceCancelCallback?

Available on UnderlyingSource<R>, provided by the UnderlyingSource$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pull ↔ UnderlyingSourcePullCallback<R>?

Available on UnderlyingSource<R>, provided by the UnderlyingSource$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start ↔ UnderlyingSourceStartCallback<R>?

Available on UnderlyingSource<R>, provided by the UnderlyingSource$Typings extension

getter/setter pair
type ↔ String?

Available on UnderlyingSource<R>, provided by the UnderlyingSource$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited