ValueTypeMap class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

ValueTypeMap({Function? anyfunc, dynamic externref, num? f32, num? f64, num? i32, int? i64, Never v128})
factory

Properties

anyfunc ↔ Function

Available on ValueTypeMap, provided by the ValueTypeMap$Typings extension

getter/setter pair
externref ↔ dynamic

Available on ValueTypeMap, provided by the ValueTypeMap$Typings extension

getter/setter pair
f32 ↔ num

Available on ValueTypeMap, provided by the ValueTypeMap$Typings extension

getter/setter pair
f64 ↔ num

Available on ValueTypeMap, provided by the ValueTypeMap$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
i32 ↔ num

Available on ValueTypeMap, provided by the ValueTypeMap$Typings extension

getter/setter pair
i64 ↔ int

Available on ValueTypeMap, provided by the ValueTypeMap$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
v128 ↔ Never

Available on ValueTypeMap, provided by the ValueTypeMap$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited