VideoColorSpace class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

VideoColorSpace([VideoColorSpaceInit? init])
factory

Properties

fullRange → bool?

Available on VideoColorSpace, provided by the VideoColorSpace$Typings extension

MDN Reference
no setter
hashCode → int
The hash code for this object.
no setterinherited
matrix → VideoMatrixCoefficients?

Available on VideoColorSpace, provided by the VideoColorSpace$Typings extension

MDN Reference
no setter
primaries → VideoColorPrimaries?

Available on VideoColorSpace, provided by the VideoColorSpace$Typings extension

MDN Reference
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toJSON ↔ VideoColorSpaceInit Function()

Available on VideoColorSpace, provided by the VideoColorSpace$Typings extension

getter/setter pair
transfer → VideoTransferCharacteristics?

Available on VideoColorSpace, provided by the VideoColorSpace$Typings extension

MDN Reference
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited