VideoColorSpaceInit class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

VideoColorSpaceInit({bool? fullRange, VideoMatrixCoefficients? matrix, VideoColorPrimaries? primaries, VideoTransferCharacteristics? transfer})
factory

Properties

fullRange ↔ bool?

Available on VideoColorSpaceInit, provided by the VideoColorSpaceInit$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
matrix ↔ VideoMatrixCoefficients?

Available on VideoColorSpaceInit, provided by the VideoColorSpaceInit$Typings extension

getter/setter pair
primaries ↔ VideoColorPrimaries?

Available on VideoColorSpaceInit, provided by the VideoColorSpaceInit$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transfer ↔ VideoTransferCharacteristics?

Available on VideoColorSpaceInit, provided by the VideoColorSpaceInit$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited