VideoDecoderConfig class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

VideoDecoderConfig({String? codec, num? codedHeight, num? codedWidth, VideoColorSpaceInit? colorSpace, Object? description, num? displayAspectHeight, num? displayAspectWidth, HardwareAcceleration? hardwareAcceleration, bool? optimizeForLatency})
factory

Properties

codec ↔ String

Available on VideoDecoderConfig, provided by the VideoDecoderConfig$Typings extension

getter/setter pair
codedHeight ↔ num?

Available on VideoDecoderConfig, provided by the VideoDecoderConfig$Typings extension

getter/setter pair
codedWidth ↔ num?

Available on VideoDecoderConfig, provided by the VideoDecoderConfig$Typings extension

getter/setter pair
colorSpace ↔ VideoColorSpaceInit?

Available on VideoDecoderConfig, provided by the VideoDecoderConfig$Typings extension

getter/setter pair
description ↔ Object?

Available on VideoDecoderConfig, provided by the VideoDecoderConfig$Typings extension

getter/setter pair
displayAspectHeight ↔ num?

Available on VideoDecoderConfig, provided by the VideoDecoderConfig$Typings extension

getter/setter pair
displayAspectWidth ↔ num?

Available on VideoDecoderConfig, provided by the VideoDecoderConfig$Typings extension

getter/setter pair
hardwareAcceleration ↔ HardwareAcceleration?

Available on VideoDecoderConfig, provided by the VideoDecoderConfig$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
optimizeForLatency ↔ bool?

Available on VideoDecoderConfig, provided by the VideoDecoderConfig$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited