VideoFrame class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

VideoFrame.$1()
factory
VideoFrame.$2(Object image, [VideoFrameInit? init])
factory
VideoFrame.$3(Object data, VideoFrameBufferInit init)
factory

Properties

allocationSize ↔ num Function([VideoFrameCopyToOptions?])

Available on VideoFrame, provided by the VideoFrame$Typings extension

getter/setter pair
clone ↔ VideoFrame Function()

Available on VideoFrame, provided by the VideoFrame$Typings extension

getter/setter pair
close ↔ void Function()

Available on VideoFrame, provided by the VideoFrame$Typings extension

getter/setter pair
codedHeight → num

Available on VideoFrame, provided by the VideoFrame$Typings extension

MDN Reference
no setter
codedRect → DOMRectReadOnly?

Available on VideoFrame, provided by the VideoFrame$Typings extension

MDN Reference
no setter
codedWidth → num

Available on VideoFrame, provided by the VideoFrame$Typings extension

MDN Reference
no setter
colorSpace → VideoColorSpace

Available on VideoFrame, provided by the VideoFrame$Typings extension

MDN Reference
no setter
copyTo ↔ Future<List<PlaneLayout>> Function(Object, [VideoFrameCopyToOptions?])

Available on VideoFrame, provided by the VideoFrame$Typings extension

getter/setter pair
displayHeight → num

Available on VideoFrame, provided by the VideoFrame$Typings extension

MDN Reference
no setter
displayWidth → num

Available on VideoFrame, provided by the VideoFrame$Typings extension

MDN Reference
no setter
duration → num?

Available on VideoFrame, provided by the VideoFrame$Typings extension

MDN Reference
no setter
format → VideoPixelFormat?

Available on VideoFrame, provided by the VideoFrame$Typings extension

MDN Reference
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → num

Available on VideoFrame, provided by the VideoFrame$Typings extension

MDN Reference
no setter
visibleRect → DOMRectReadOnly?

Available on VideoFrame, provided by the VideoFrame$Typings extension

MDN Reference
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited