VideoFrameBufferInit class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

VideoFrameBufferInit({num? codedHeight, num? codedWidth, VideoColorSpaceInit? colorSpace, num? displayHeight, num? displayWidth, num? duration, VideoPixelFormat? format, List<PlaneLayout>? layout, num? timestamp, DOMRectInit? visibleRect})
factory

Properties

codedHeight ↔ num

Available on VideoFrameBufferInit, provided by the VideoFrameBufferInit$Typings extension

getter/setter pair
codedWidth ↔ num

Available on VideoFrameBufferInit, provided by the VideoFrameBufferInit$Typings extension

getter/setter pair
colorSpace ↔ VideoColorSpaceInit?

Available on VideoFrameBufferInit, provided by the VideoFrameBufferInit$Typings extension

getter/setter pair
displayHeight ↔ num?

Available on VideoFrameBufferInit, provided by the VideoFrameBufferInit$Typings extension

getter/setter pair
displayWidth ↔ num?

Available on VideoFrameBufferInit, provided by the VideoFrameBufferInit$Typings extension

getter/setter pair
duration ↔ num?

Available on VideoFrameBufferInit, provided by the VideoFrameBufferInit$Typings extension

getter/setter pair
format ↔ VideoPixelFormat

Available on VideoFrameBufferInit, provided by the VideoFrameBufferInit$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
layout ↔ List<PlaneLayout>?

Available on VideoFrameBufferInit, provided by the VideoFrameBufferInit$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp ↔ num

Available on VideoFrameBufferInit, provided by the VideoFrameBufferInit$Typings extension

getter/setter pair
visibleRect ↔ DOMRectInit?

Available on VideoFrameBufferInit, provided by the VideoFrameBufferInit$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited