VideoFrameInit class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

VideoFrameInit({AlphaOption? alpha, num? displayHeight, num? displayWidth, num? duration, num? timestamp, DOMRectInit? visibleRect})
factory

Properties

alpha ↔ AlphaOption?

Available on VideoFrameInit, provided by the VideoFrameInit$Typings extension

getter/setter pair
displayHeight ↔ num?

Available on VideoFrameInit, provided by the VideoFrameInit$Typings extension

getter/setter pair
displayWidth ↔ num?

Available on VideoFrameInit, provided by the VideoFrameInit$Typings extension

getter/setter pair
duration ↔ num?

Available on VideoFrameInit, provided by the VideoFrameInit$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp ↔ num?

Available on VideoFrameInit, provided by the VideoFrameInit$Typings extension

getter/setter pair
visibleRect ↔ DOMRectInit?

Available on VideoFrameInit, provided by the VideoFrameInit$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited