WEBGLColorBufferFloat class

Available extensions
Annotations
  • @JS.new('WEBGL_color_buffer_float')
  • @staticInterop
  • @anonymous

Constructors

WEBGLColorBufferFloat({num? rgba32fExt, num? framebufferAttachmentComponentTypeExt, num? unsignedNormalizedExt})
factory

Properties

framebufferAttachmentComponentTypeExt → num

Available on WEBGLColorBufferFloat, provided by the WEBGLColorBufferFloat$Typings extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
rgba32fExt → num

Available on WEBGLColorBufferFloat, provided by the WEBGLColorBufferFloat$Typings extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unsignedNormalizedExt → num

Available on WEBGLColorBufferFloat, provided by the WEBGLColorBufferFloat$Typings extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

framebufferAttachmentComponentTypeExt → num
no setter
rgba32fExt → num
no setter
unsignedNormalizedExt → num
no setter