WEBGLDepthTexture class

The WEBGL_depth_texture extension is part of the WebGL API and defines 2D depth and depth-stencil textures.

MDN Reference

Available extensions
Annotations
  • @JS.new('WEBGL_depth_texture')
  • @staticInterop
  • @anonymous

Constructors

WEBGLDepthTexture({num? unsignedInt248Webgl})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unsignedInt248Webgl → num

Available on WEBGLDepthTexture, provided by the WEBGLDepthTexture$Typings extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

unsignedInt248Webgl → num
no setter