WebGLContextAttributes class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

WebGLContextAttributes({bool? alpha, bool? antialias, bool? depth, bool? desynchronized, bool? failIfMajorPerformanceCaveat, WebGLPowerPreference? powerPreference, bool? premultipliedAlpha, bool? preserveDrawingBuffer, bool? stencil})
factory

Properties

alpha ↔ bool?

Available on WebGLContextAttributes, provided by the WebGLContextAttributes$Typings extension

getter/setter pair
antialias ↔ bool?

Available on WebGLContextAttributes, provided by the WebGLContextAttributes$Typings extension

getter/setter pair
depth ↔ bool?

Available on WebGLContextAttributes, provided by the WebGLContextAttributes$Typings extension

getter/setter pair
desynchronized ↔ bool?

Available on WebGLContextAttributes, provided by the WebGLContextAttributes$Typings extension

getter/setter pair
failIfMajorPerformanceCaveat ↔ bool?

Available on WebGLContextAttributes, provided by the WebGLContextAttributes$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
powerPreference ↔ WebGLPowerPreference?

Available on WebGLContextAttributes, provided by the WebGLContextAttributes$Typings extension

getter/setter pair
premultipliedAlpha ↔ bool?

Available on WebGLContextAttributes, provided by the WebGLContextAttributes$Typings extension

getter/setter pair
preserveDrawingBuffer ↔ bool?

Available on WebGLContextAttributes, provided by the WebGLContextAttributes$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stencil ↔ bool?

Available on WebGLContextAttributes, provided by the WebGLContextAttributes$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited