WindowClient class

This ServiceWorker API interface represents the scope of a service worker client that is a document in a browser context, controlled by an active worker. The service worker client independently selects and uses a service worker for its own loading and sub-resources.

MDN Reference

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

WindowClient()
factory

Properties

focus ↔ Future<WindowClient> Function()

Available on WindowClient, provided by the WindowClient$Typings extension

getter/setter pair
focused → bool

Available on WindowClient, provided by the WindowClient$Typings extension

MDN Reference
no setter
frameType → FrameType

Available on Client, provided by the Client$Typings extension

MDN Reference
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String

Available on Client, provided by the Client$Typings extension

MDN Reference
no setter

Available on WindowClient, provided by the WindowClient$Typings extension

getter/setter pair
postMessage → ({void Function(List<Object> transfer, [dynamic message]) $1, void Function([dynamic message, StructuredSerializeOptions? options]) $2})

Available on Client, provided by the Client$Typings extension

Overload accessor: $1, $2
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ClientTypes

Available on Client, provided by the Client$Typings extension

MDN Reference
no setter
url → String

Available on Client, provided by the Client$Typings extension

MDN Reference
no setter
visibilityState → DocumentVisibilityState

Available on WindowClient, provided by the WindowClient$Typings extension

MDN Reference
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited