WorkerNavigator class

A subset of the Navigator interface allowed to be accessed from a Worker. Such an object is initialized for each worker and is available via the WorkerGlobalScope.navigator property obtained by calling window.self.navigator.

MDN Reference

Implemented types
Available extensions
Annotations
  • @JS.new()
  • @staticInterop

Constructors

WorkerNavigator()
factory

Properties

appCodeName → String

Available on NavigatorID, provided by the NavigatorID$Typings extension

no setter
appName → String

Available on NavigatorID, provided by the NavigatorID$Typings extension

no setter
appVersion → String

Available on NavigatorID, provided by the NavigatorID$Typings extension

no setter
clearAppBadge ↔ Future<void> Function()

Available on NavigatorBadge, provided by the NavigatorBadge$Typings extension

getter/setter pair
hardwareConcurrency → num

Available on NavigatorConcurrentHardware, provided by the NavigatorConcurrentHardware$Typings extension

MDN Reference
no setter
hashCode → int
The hash code for this object.
no setterinherited
language → String

Available on NavigatorLanguage, provided by the NavigatorLanguage$Typings extension

MDN Reference
no setter
languages → ReadonlyArray<String>

Available on NavigatorLanguage, provided by the NavigatorLanguage$Typings extension

MDN Reference
no setter
locks → LockManager

Available on NavigatorLocks, provided by the NavigatorLocks$Typings extension

MDN Reference
no setter
mediaCapabilities → MediaCapabilities

Available on WorkerNavigator, provided by the WorkerNavigator$Typings extension

MDN Reference
no setter
onLine → bool

Available on NavigatorOnLine, provided by the NavigatorOnLine$Typings extension

MDN Reference
no setter
permissions → Permissions

Available on WorkerNavigator, provided by the WorkerNavigator$Typings extension

MDN Reference
no setter
platform → String

Available on NavigatorID, provided by the NavigatorID$Typings extension

no setter
product → String

Available on NavigatorID, provided by the NavigatorID$Typings extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setAppBadge ↔ Future<void> Function([num?])

Available on NavigatorBadge, provided by the NavigatorBadge$Typings extension

getter/setter pair
storage → StorageManager

Available on NavigatorStorage, provided by the NavigatorStorage$Typings extension

MDN Reference
no setter
userAgent → String

Available on NavigatorID, provided by the NavigatorID$Typings extension

MDN Reference
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited