WorkerOptions class

Available extensions
Annotations
  • @JS.new()
  • @staticInterop
  • @anonymous

Constructors

WorkerOptions({RequestCredentials? credentials, String? name, WorkerType? type})
factory

Properties

credentials ↔ RequestCredentials?

Available on WorkerOptions, provided by the WorkerOptions$Typings extension

getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?

Available on WorkerOptions, provided by the WorkerOptions$Typings extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ WorkerType?

Available on WorkerOptions, provided by the WorkerOptions$Typings extension

getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited